@@ -9,8 +9,8 @@
  *     Christian Schulte, 2001
  *
  *  Last modified:
- *     $Date: 2010-07-02 10:59:05 +0200 (Fri, 02 Jul 2010) $ by $Author: schulte $
- *     $Revision: 11148 $
+ *     $Date: 2011-02-01 14:31:23 +0100 (Tue, 01 Feb 2011) $ by $Author: schulte $
+ *     $Revision: 11595 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -230,7 +230,7 @@ public:
  * the knight does a full tour (last move reaches first move
  * again). The formulation is due to Gert Smolka.
  *
- * \ingroup ExProblem
+ * \ingroup Example
  *
  */
 class KnightsReified : public Knights {
@@ -283,7 +283,7 @@ public:
  * knights do a full tour by knights move (last knight reaches
  * first knight again).
  *
- * \ingroup ExProblem
+ * \ingroup Example
  *
  */
 class KnightsCircuit : public Knights {
@@ -306,6 +306,12 @@ public:
   }
 };
 
+/*
+ * Just to fool some scripts:
+ * \brief %Example: n-Knight's tour
+ *
+ */
+
 #ifdef GECODE_HAS_GIST
 /// Inspector showing knight moves on a chess board
 class KnightsInspector : public Gist::Inspector {
@@ -378,7 +384,7 @@ public:
     mw = NULL;
   }
 };
-#endif GECODE_HAS_GIST
+#endif
 
 /** \brief Main-function
  *  \relates Knights
