@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2010-07-14 20:32:01 +0200 (Wed, 14 Jul 2010) $ by $Author: schulte $
- *     $Revision: 11195 $
+ *     $Date: 2010-10-06 22:44:30 +0200 (Wed, 06 Oct 2010) $ by $Author: schulte $
+ *     $Revision: 11465 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -404,6 +404,15 @@ namespace Gecode {
     return _size;
   }
   
+  /*
+   * Options with additional string argument
+   *
+   */
+  inline const char*
+  InstanceOptions::instance(void) const {
+    return _inst;
+  }
+  
 }
 
 // STATISTICS: driver-any
