@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2010-06-01 13:59:14 +0200 (Tue, 01 Jun 2010) $ by $Author: tack $
- *     $Revision: 10996 $
+ *     $Date: 2010-10-09 13:58:12 +0200 (Sat, 09 Oct 2010) $ by $Author: schulte $
+ *     $Revision: 11498 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -167,15 +167,6 @@ namespace Gecode { namespace Driver {
     }
   };
   
-  /// Specialization for LDS
-  template<typename S>
-  class GistEngine<LDS<S> > {
-  public:
-    static void explore(S* root, const Gist::Options& opt) {
-      (void) Gist::dfs(root, opt);
-    }
-  };
-  
   /// Specialization for BAB
   template<typename S>
   class GistEngine<BAB<S> > {
