@@ -7,8 +7,8 @@
  *     Guido Tack, 2007
  *
  *  Last modified:
- *     $Date: 2010-05-11 12:33:38 +0200 (Tue, 11 May 2010) $ by $Author: tack $
- *     $Revision: 10940 $
+ *     $Date: 2010-10-09 13:58:12 +0200 (Sat, 09 Oct 2010) $ by $Author: schulte $
+ *     $Revision: 11498 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -572,19 +572,6 @@ namespace Gecode { namespace FlatZinc {
     }
   };
 
-  /// Specialization for LDS
-  template<typename S>
-  class GistEngine<LDS<S> > {
-  public:
-    static void explore(S* root, const FlatZincOptions& opt,
-                        Gist::Inspector* i) {
-      Gecode::Gist::Options o;
-      o.c_d = opt.c_d(); o.a_d = opt.a_d();
-      o.inspect.click(i);
-      (void) Gecode::Gist::dfs(root, o);
-    }
-  };
-
   /// Specialization for BAB
   template<typename S>
   class GistEngine<BAB<S> > {
