@@ -7,8 +7,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2010-04-21 14:22:14 +0200 (Wed, 21 Apr 2010) $ by $Author: tack $
- *     $Revision: 10784 $
+ *     $Date: 2010-08-12 10:29:27 +0200 (Thu, 12 Aug 2010) $ by $Author: tack $
+ *     $Revision: 11346 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -82,8 +82,6 @@ namespace Gecode { namespace Gist {
     autoZoomButton->setIcon(myPic);
 
     nodeStatInspector = new NodeStatInspector(this);
-    connect(canvas, SIGNAL(statusChanged(VisualNode*,const Statistics&, bool)),
-            nodeStatInspector, SLOT(node(VisualNode*,const Statistics&, bool)));
 
     inspect = new QAction("Inspect", this);
     inspect->setShortcut(QKeySequence("Return"));
@@ -548,6 +546,7 @@ namespace Gecode { namespace Gist {
   void
   Gist::on_canvas_statusChanged(VisualNode* n, const Statistics& stats,
                                 bool finished) {
+    nodeStatInspector->node(*canvas->na,n,stats,finished);
     if (!finished) {
       inspect->setEnabled(false);
       inspectGroup->setEnabled(false);
@@ -629,33 +628,32 @@ namespace Gecode { namespace Gist {
         compareNodeBeforeFP->setEnabled(true);
       }
 
-      VisualNode* p = n->getParent();
+      navRoot->setEnabled(true);
+      VisualNode* p = n->getParent(*canvas->na);
       if (p == NULL) {
         inspectBeforeFP->setEnabled(false);
         inspectBeforeFPGroup->setEnabled(false);
-        navRoot->setEnabled(false);
         navUp->setEnabled(false);
         navRight->setEnabled(false);
         navLeft->setEnabled(false);
       } else {
-        navRoot->setEnabled(true);
         navUp->setEnabled(true);
-        unsigned int alt = n->getAlternative();
+        unsigned int alt = n->getAlternative(*canvas->na);
         navRight->setEnabled(alt + 1 < p->getNumberOfChildren());
         navLeft->setEnabled(alt > 0);
       }
 
       VisualNode* root = n;
       while (!root->isRoot())
-        root = root->getParent();
-      NextSolCursor nsc(n, false);
+        root = root->getParent(*canvas->na);
+      NextSolCursor nsc(n, false, *canvas->na);
       PreorderNodeVisitor<NextSolCursor> nsv(nsc);
-      while (nsv.next()) {}
+      nsv.run();
       navNextSol->setEnabled(nsv.getCursor().node() != root);
 
-      NextSolCursor psc(n, true);
+      NextSolCursor psc(n, true, *canvas->na);
       PreorderNodeVisitor<NextSolCursor> psv(psc);
-      while (psv.next()) {}
+      psv.run();
       navPrevSol->setEnabled(psv.getCursor().node() != root);
 
       zoomToFit->setEnabled(true);
@@ -769,6 +767,8 @@ namespace Gecode { namespace Gist {
   Gist::getAutoZoom(void) { return canvas->getAutoZoom(); }
   void
   Gist::setRefresh(int i) { canvas->setRefresh(i); }
+  void
+  Gist::setRefreshPause(int i) { canvas->setRefreshPause(i); }
   bool
   Gist::getSmoothScrollAndZoom(void) {
     return canvas->getSmoothScrollAndZoom();
