@@ -7,8 +7,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2010-05-11 11:00:07 +0200 (Tue, 11 May 2010) $ by $Author: tack $
- *     $Revision: 10936 $
+ *     $Date: 2010-09-30 09:44:05 +0200 (Thu, 30 Sep 2010) $ by $Author: tack $
+ *     $Revision: 11431 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -43,7 +43,6 @@
 #include <gecode/gist/treecanvas.hh>
 
 #include <gecode/gist/nodevisitor.hh>
-#include <gecode/gist/layoutcursor.hh>
 #include <gecode/gist/visualnode.hh>
 #include <gecode/gist/drawingcursor.hh>
 
@@ -60,7 +59,7 @@ namespace Gecode { namespace Gist {
     , finishedFlag(false)
     , compareNodes(false), compareNodesBeforeFP(false)
     , autoHideFailed(true), autoZoom(false)
-    , refresh(500), smoothScrollAndZoom(false)
+    , refresh(500), refreshPause(0), smoothScrollAndZoom(false)
     , zoomTimeLine(500)
     , scrollTimeLine(1000), targetX(0), sourceX(0), targetY(0), sourceY(0)
     , targetW(0), targetH(0), targetScale(0)
@@ -72,9 +71,11 @@ namespace Gecode { namespace Gist {
       } else {
         rootSpace = Gecode::Search::snapshot(rootSpace,opt);
       }
-      na = new Node::NodeAllocator();
-      root = new (*na) VisualNode(rootSpace);
-      root->layout();
+      na = new Node::NodeAllocator(bab);
+      int rootIdx = na->allocate(rootSpace);
+      assert(rootIdx == 0); (void) rootIdx;
+      root = (*na)[0];
+      root->layout(*na);
       root->setMarked(true);
       currentNode = root;
       pathHead = root;
@@ -119,7 +120,13 @@ namespace Gecode { namespace Gist {
       update();
   }
 
-  TreeCanvas::~TreeCanvas(void) { delete root; delete na; }
+  TreeCanvas::~TreeCanvas(void) {
+    if (root) {
+      DisposeCursor dc(root,*na);
+      PreorderNodeVisitor<DisposeCursor>(dc).run();
+    }
+    delete na;
+  }
 
   void
   TreeCanvas::addDoubleClickInspector(Inspector* i) {
@@ -214,7 +221,7 @@ namespace Gecode { namespace Gist {
     QMutexLocker locker(&mutex);
     layoutMutex.lock();
     if (root != NULL) {
-      root->layout();
+      root->layout(*na);
       BoundingBox bb = root->getBoundingBox();
 
       int w = static_cast<int>((bb.right-bb.left+Layout::extent)*scale);
@@ -272,7 +279,7 @@ namespace Gecode { namespace Gist {
     node = n;
     
     depth = -1;
-    for (VisualNode* p = n; p != NULL; p = p->getParent())
+    for (VisualNode* p = n; p != NULL; p = p->getParent(*ti->na))
       depth++;
     
     a = all;
@@ -287,9 +294,9 @@ namespace Gecode { namespace Gist {
       return;
 
     if (t->autoHideFailed) {
-      t->root->hideFailed();
+      t->root->hideFailed(*t->na,true);
     }
-    for (VisualNode* n = t->currentNode; n != NULL; n = n->getParent()) {
+    for (VisualNode* n = t->currentNode; n != NULL; n=n->getParent(*t->na)) {
       if (n->isHidden()) {
         t->currentNode->setMarked(false);
         t->currentNode = n;
@@ -298,7 +305,7 @@ namespace Gecode { namespace Gist {
       }
     }
     
-    t->root->layout();
+    t->root->layout(*t->na);
     BoundingBox bb = t->root->getBoundingBox();
 
     int w = static_cast<int>((bb.right-bb.left+Layout::extent)*t->scale);
@@ -377,26 +384,30 @@ namespace Gecode { namespace Gist {
       int nodeCount = 0;
       t->stopSearchFlag = false;
       while (!stck.empty() && !t->stopSearchFlag) {
-        if (t->refresh > 0 && ++nodeCount > t->refresh) {
-          node->dirtyUp();
+        if (t->refresh > 0 && nodeCount >= t->refresh) {
+          node->dirtyUp(*t->na);
           updateCanvas();
           emit statusChanged(false);
           nodeCount = 0;
+          if (t->refreshPause > 0)
+            msleep(t->refreshPause);
         }
         SearchItem& si = stck.top();
         si.i++;
         if (si.i == si.noOfChildren) {
           stck.pop();
         } else {
-          VisualNode* n = si.n->getChild(si.i);
+          VisualNode* n = si.n->getChild(*t->na,si.i);
           if (n->isOpen()) {
+            if (n->getStatus() == UNDETERMINED)
+              nodeCount++;
             kids = n->getNumberOfChildNodes(*t->na, t->curBest, t->stats,
                                             t->c_d, t->a_d);
             if (kids == 0) {
               if (n->getStatus() == SOLVED) {
-                assert(n->hasWorkingSpace());
+                assert(n->hasCopy());
                 emit solution(n->getWorkingSpace());
-                n->purge();
+                n->purge(*t->na);
                 sol = n;
                 if (!a)
                   break;
@@ -413,7 +424,7 @@ namespace Gecode { namespace Gist {
           }
         }
       }
-      node->dirtyUp();
+      node->dirtyUp(*t->na);
       t->stopSearchFlag = false;
       t->mutex.unlock();
       if (sol != NULL) {
@@ -443,7 +454,7 @@ namespace Gecode { namespace Gist {
   void
   TreeCanvas::toggleHidden(void) {
     QMutexLocker locker(&mutex);
-    currentNode->toggleHidden();
+    currentNode->toggleHidden(*na);
     update();
     centerCurrentNode();
     emit statusChanged(currentNode, stats, true);
@@ -452,7 +463,7 @@ namespace Gecode { namespace Gist {
   void
   TreeCanvas::hideFailed(void) {
     QMutexLocker locker(&mutex);
-    currentNode->hideFailed();
+    currentNode->hideFailed(*na);
     update();
     centerCurrentNode();
     emit statusChanged(currentNode, stats, true);
@@ -462,7 +473,7 @@ namespace Gecode { namespace Gist {
   TreeCanvas::unhideAll(void) {
     QMutexLocker locker(&mutex);
     QMutexLocker layoutLocker(&layoutMutex);
-    currentNode->unhideAll();
+    currentNode->unhideAll(*na);
     update();
     centerCurrentNode();
     emit statusChanged(currentNode, stats, true);
@@ -471,7 +482,7 @@ namespace Gecode { namespace Gist {
   void
   TreeCanvas::toggleStop(void) {
     QMutexLocker locker(&mutex);
-    currentNode->toggleStop();
+    currentNode->toggleStop(*na);
     update();
     centerCurrentNode();
     emit statusChanged(currentNode, stats, true);
@@ -481,7 +492,7 @@ namespace Gecode { namespace Gist {
   TreeCanvas::unstopAll(void) {
     QMutexLocker locker(&mutex);
     QMutexLocker layoutLocker(&layoutMutex);
-    currentNode->unstopAll();
+    currentNode->unstopAll(*na);
     update();
     centerCurrentNode();
     emit statusChanged(currentNode, stats, true);    
@@ -553,7 +564,7 @@ namespace Gecode { namespace Gist {
     while (c != NULL) {
       x += c->getOffset();
       y += Layout::dist_y;
-      c = c->getParent();
+      c = c->getParent(*na);
     }
 
     x = static_cast<int>((xtrans+x)*scale); y = static_cast<int>(y*scale);
@@ -608,6 +619,7 @@ namespace Gecode { namespace Gist {
 
     int failedInspectorType = -1;
     int failedInspector = -1;
+    bool needCentering = false;
     try {
       switch (currentNode->getStatus()) {
       case UNDETERMINED:
@@ -615,16 +627,18 @@ namespace Gecode { namespace Gist {
             unsigned int kids =  
               currentNode->getNumberOfChildNodes(*na,curBest,stats,c_d,a_d);
             int depth = -1;
-            for (VisualNode* p = currentNode; p != NULL; p = p->getParent())
+            for (VisualNode* p = currentNode; p != NULL; p=p->getParent(*na))
               depth++;
-            if (kids > 0)
+            if (kids > 0) {
+              needCentering = true;
               depth++;
+            }
             stats.maxDepth =
               std::max(stats.maxDepth, depth);
             if (currentNode->getStatus() == SOLVED) {
-              assert(currentNode->hasWorkingSpace());
+              assert(currentNode->hasCopy());
               emit solution(currentNode->getWorkingSpace());
-              currentNode->purge();
+              currentNode->purge(*na);
             }
             emit statusChanged(currentNode,stats,true);
             for (int i=0; i<moveInspectors.size(); i++) {
@@ -660,7 +674,7 @@ namespace Gecode { namespace Gist {
           if (fix) {
             if (currentNode->isRoot() && currentNode->getStatus() == FAILED)
               break;
-            curSpace = currentNode->getSpace(curBest,c_d,a_d);
+            curSpace = currentNode->getSpace(*na,curBest,c_d,a_d);
             if (currentNode->getStatus() == SOLVED &&
                 curSpace->status() != SS_SOLVED) {
               // in the presence of weakly monotonic propagators, we may have to
@@ -672,14 +686,15 @@ namespace Gecode { namespace Gist {
           } else {
             if (currentNode->isRoot())
               break;
-            VisualNode* p = currentNode->getParent();
-            curSpace = p->getSpace(curBest,c_d,a_d);
+            VisualNode* p = currentNode->getParent(*na);
+            curSpace = p->getSpace(*na,curBest,c_d,a_d);
             switch (curSpace->status()) {
             case SS_SOLVED:
             case SS_FAILED:
               break;
             case SS_BRANCH:
-              curSpace->commit(*p->getChoice(), currentNode->getAlternative());
+              curSpace->commit(*p->getChoice(), 
+                               currentNode->getAlternative(*na));
               break;
             default:
               GECODE_NEVER;
@@ -724,9 +739,10 @@ namespace Gecode { namespace Gist {
       std::exit(EXIT_FAILURE);
     }
 
-    currentNode->dirtyUp();
+    currentNode->dirtyUp(*na);
     update();
-    centerCurrentNode();
+    if (needCentering)
+      centerCurrentNode();
   }
   
   void
@@ -791,15 +807,21 @@ namespace Gecode { namespace Gist {
   TreeCanvas::reset(void) {
     QMutexLocker locker(&mutex);
     Space* rootSpace =
-      root->getStatus() == FAILED ? NULL : root->getSpace(curBest,c_d,a_d);
+      root->getStatus() == FAILED ? NULL : 
+                           root->getSpace(*na,curBest,c_d,a_d);
     if (curBest != NULL) {
       delete curBest;
       curBest = new BestNode(NULL);
     }
-    delete root;
+    if (root) {
+      DisposeCursor dc(root,*na);
+      PreorderNodeVisitor<DisposeCursor>(dc).run();
+    }
     delete na;
-    na = new Node::NodeAllocator();
-    root = new (*na) VisualNode(rootSpace);
+    na = new Node::NodeAllocator(curBest != NULL);
+    int rootIdx = na->allocate(rootSpace);
+    assert(rootIdx == 0); (void) rootIdx;
+    root = (*na)[0];
     root->setMarked(true);
     currentNode = root;
     pathHead = root;
@@ -808,7 +830,7 @@ namespace Gecode { namespace Gist {
     for (int i=bookmarks.size(); i--;)
       emit removedBookmark(i);
     bookmarks.clear();
-    root->layout();
+    root->layout(*na);
 
     emit statusChanged(currentNode, stats, true);
     update();
@@ -835,7 +857,7 @@ namespace Gecode { namespace Gist {
       bookmarks.remove(idx);
       emit removedBookmark(idx);
     }
-    currentNode->dirtyUp();
+    currentNode->dirtyUp(*na);
     update();
   }
   
@@ -845,11 +867,11 @@ namespace Gecode { namespace Gist {
     if(currentNode == pathHead)
       return;
 
-    pathHead->unPathUp();
+    pathHead->unPathUp(*na);
     pathHead = currentNode;
 
-    currentNode->pathUp();
-    currentNode->dirtyUp();
+    currentNode->pathUp(*na);
+    currentNode->dirtyUp(*na);
     update();
   }
 
@@ -859,11 +881,11 @@ namespace Gecode { namespace Gist {
     setCurrentNode(root);
     if (currentNode->isOnPath()) {
       inspectCurrentNode();
-      int nextAlt = currentNode->getPathAlternative();
+      int nextAlt = currentNode->getPathAlternative(*na);
       while (nextAlt >= 0) {
-        setCurrentNode(currentNode->getChild(nextAlt));
+        setCurrentNode(currentNode->getChild(*na,nextAlt));
         inspectCurrentNode();
-        nextAlt = currentNode->getPathAlternative();
+        nextAlt = currentNode->getPathAlternative(*na);
       }
     }
     update();
@@ -894,7 +916,7 @@ namespace Gecode { namespace Gist {
   TreeCanvas::navUp(void) {
     QMutexLocker locker(&mutex);
 
-    VisualNode* p = currentNode->getParent();
+    VisualNode* p = currentNode->getParent(*na);
 
     setCurrentNode(p);
 
@@ -912,8 +934,8 @@ namespace Gecode { namespace Gist {
       case UNSTOP:
       case BRANCH:
           {
-            int alt = std::max(0, currentNode->getPathAlternative());
-            VisualNode* n = currentNode->getChild(alt);
+            int alt = std::max(0, currentNode->getPathAlternative(*na));
+            VisualNode* n = currentNode->getChild(*na,alt);
             setCurrentNode(n);
             centerCurrentNode();
             break;
@@ -929,11 +951,11 @@ namespace Gecode { namespace Gist {
   void
   TreeCanvas::navLeft(void) {
     QMutexLocker locker(&mutex);
-    VisualNode* p = currentNode->getParent();
+    VisualNode* p = currentNode->getParent(*na);
     if (p != NULL) {
-      int alt = currentNode->getAlternative();
+      int alt = currentNode->getAlternative(*na);
       if (alt > 0) {
-        VisualNode* n = p->getChild(alt-1);
+        VisualNode* n = p->getChild(*na,alt-1);
         setCurrentNode(n);
         centerCurrentNode();
       }
@@ -943,11 +965,11 @@ namespace Gecode { namespace Gist {
   void
   TreeCanvas::navRight(void) {
     QMutexLocker locker(&mutex);
-    VisualNode* p = currentNode->getParent();
+    VisualNode* p = currentNode->getParent(*na);
     if (p != NULL) {
-      unsigned int alt = currentNode->getAlternative();
+      unsigned int alt = currentNode->getAlternative(*na);
       if (alt + 1 < p->getNumberOfChildren()) {
-        VisualNode* n = p->getChild(alt+1);
+        VisualNode* n = p->getChild(*na,alt+1);
         setCurrentNode(n);
         centerCurrentNode();
       }
@@ -964,11 +986,12 @@ namespace Gecode { namespace Gist {
   void
   TreeCanvas::navNextSol(bool back) {
     QMutexLocker locker(&mutex);
-    NextSolCursor nsc(currentNode, back);
+    NextSolCursor nsc(currentNode,back,*na);
     PreorderNodeVisitor<NextSolCursor> nsv(nsc);
-    while (nsv.next()) {}
-    if (nsv.getCursor().node() != root) {
-      setCurrentNode(nsv.getCursor().node());
+    nsv.run();
+    VisualNode* n = nsv.getCursor().node();
+    if (n != root) {
+      setCurrentNode(n);
       centerCurrentNode();
     }
   }
@@ -1011,10 +1034,9 @@ namespace Gecode { namespace Gist {
 
       painter.translate(printxtrans, Layout::dist_y / 2);
       QRect clip(0,0,0,0);
-      DrawingCursor dc(n, curBest, painter, clip, showCopies);
+      DrawingCursor dc(n, *na, curBest, painter, clip, showCopies);
       currentNode->setMarked(false);
-      PreorderNodeVisitor<DrawingCursor> v(dc);
-      while (v.next()) {}
+      PreorderNodeVisitor<DrawingCursor>(dc).run();
       currentNode->setMarked(true);
     }
 #else
@@ -1063,9 +1085,8 @@ namespace Gecode { namespace Gist {
       painter.scale(printScale,printScale);
       painter.translate(xtrans, 0);
       QRect clip(0,0,0,0);
-      DrawingCursor dc(root, curBest, painter, clip, showCopies);
-      PreorderNodeVisitor<DrawingCursor> v(dc);
-      while (v.next()) {}
+      DrawingCursor dc(root, *na, curBest, painter, clip, showCopies);
+      PreorderNodeVisitor<DrawingCursor>(dc).run();
     }
   }
 
@@ -1113,7 +1134,8 @@ namespace Gecode { namespace Gist {
       xoff -= (sa->viewport()->width()-w)/2;
     
     VisualNode* n;
-    n = root->findNode(static_cast<int>(x/scale-xtrans+xoff),
+    n = root->findNode(*na,
+                       static_cast<int>(x/scale-xtrans+xoff),
                        static_cast<int>((y-30)/scale+yoff));
     return n;
   }
@@ -1168,10 +1190,8 @@ namespace Gecode { namespace Gist {
                static_cast<int>(origClip.y()/scale+yoff),
                static_cast<int>(origClip.width()/scale),
                static_cast<int>(origClip.height()/scale));
-    DrawingCursor dc(root, curBest, painter, clip, showCopies);
-    PreorderNodeVisitor<DrawingCursor> v(dc);
-
-    while (v.next()) {}
+    DrawingCursor dc(root, *na, curBest, painter, clip, showCopies);
+    PreorderNodeVisitor<DrawingCursor>(dc).run();
 
     // int nodesLayouted = 1;
     // clock_t t0 = clock();
@@ -1269,7 +1289,7 @@ namespace Gecode { namespace Gist {
       for (int i=0; i<moveInspectors.size(); i++) {
         if (moveInspectors[i].second) {
           if (curSpace == NULL)
-            curSpace = n->getSpace(curBest,c_d,a_d);
+            curSpace = n->getSpace(*na,curBest,c_d,a_d);
           try {
             moveInspectors[i].first->inspect(*curSpace);
           } catch (Exception e) {
@@ -1308,20 +1328,20 @@ namespace Gecode { namespace Gist {
             for (int i=0; i<comparators.size(); i++) {
               if (comparators[i].second) {
                 if (curSpace == NULL) {
-                  curSpace = currentNode->getSpace(curBest,c_d,a_d);
+                  curSpace = currentNode->getSpace(*na,curBest,c_d,a_d);
 
                   if (!compareNodesBeforeFP || n->isRoot()) {
-                    compareSpace = n->getSpace(curBest,c_d,a_d);
+                    compareSpace = n->getSpace(*na,curBest,c_d,a_d);
                   } else {
-                    VisualNode* p = n->getParent();
-                    compareSpace = p->getSpace(curBest,c_d,a_d);
+                    VisualNode* p = n->getParent(*na);
+                    compareSpace = p->getSpace(*na,curBest,c_d,a_d);
                     switch (compareSpace->status()) {
                     case SS_SOLVED:
                     case SS_FAILED:
                       break;
                     case SS_BRANCH:
                       compareSpace->commit(*p->getChoice(), 
-                                           n->getAlternative());
+                                           n->getAlternative(*na));
                       break;
                     default:
                       GECODE_NEVER;
@@ -1392,6 +1412,13 @@ namespace Gecode { namespace Gist {
     refresh = i;
   }
 
+  void
+  TreeCanvas::setRefreshPause(int i) {
+    refreshPause = i;
+    if (refreshPause > 0)
+      refresh = 1;
+  }
+
   bool
   TreeCanvas::getSmoothScrollAndZoom(void) {
     return smoothScrollAndZoom;
