@@ -7,8 +7,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2010-03-31 11:23:42 +0200 (Wed, 31 Mar 2010) $ by $Author: tack $
- *     $Revision: 10619 $
+ *     $Date: 2010-09-03 13:50:47 +0200 (Fri, 03 Sep 2010) $ by $Author: tack $
+ *     $Revision: 11389 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -52,8 +52,11 @@ namespace Gecode { namespace Gist {
   public:
     /// Constructor
     ShapeAllocator(void) {
-      Shape::leaf = Shape::allocate(Extent(Layout::extent));
-      Shape::hidden = Shape::allocate(Extent(Layout::extent), Shape::leaf);
+      Shape::leaf = Shape::allocate(1);
+      Shape::hidden = Shape::allocate(2);
+      (*Shape::hidden)[1] = Extent(Layout::extent);
+      Shape::leaf->computeBoundingBox();
+      Shape::hidden->computeBoundingBox();
     }
     ~ShapeAllocator(void) {
       Shape::deallocate(Shape::leaf);
@@ -64,11 +67,11 @@ namespace Gecode { namespace Gist {
   /// Allocate shapes statically
   ShapeAllocator shapeAllocator;
 
-  VisualNode::VisualNode(void)
-  : shape(NULL)
+  VisualNode::VisualNode(int p)
+  : SpaceNode(p)
   , offset(0)
-  , box(0,0)
   {
+    shape = NULL;
     setDirty(true);
     setChildrenLayoutDone(false);
     setHidden(false);
@@ -79,10 +82,9 @@ namespace Gecode { namespace Gist {
 
   VisualNode::VisualNode(Space* root)
   : SpaceNode(root)
-  , shape(NULL)
   , offset(0)
-  , box(0,0)
   {
+    shape = NULL;
     setDirty(true);
     setChildrenLayoutDone(false);
     setHidden(false);
@@ -91,28 +93,30 @@ namespace Gecode { namespace Gist {
     setBookmarked(false);
   }
 
-  VisualNode::~VisualNode(void) {
+  void
+  VisualNode::dispose(void) {
     Shape::deallocate(shape);
+    SpaceNode::dispose();
   }
 
   void
-  VisualNode::dirtyUp(void) {
+  VisualNode::dirtyUp(const NodeAllocator& na) {
     VisualNode* cur = this;
     while (!cur->isDirty()) {
       cur->setDirty(true);
       if (! cur->isRoot()) {
-        cur = cur->getParent();
+        cur = cur->getParent(na);
       }
     }
   }
 
   void
-  VisualNode::layout(void) {
-    LayoutCursor l(this);
-    PostorderNodeVisitor<LayoutCursor> p(l);
+  VisualNode::layout(const NodeAllocator& na) {
+    LayoutCursor l(this,na);
+    PostorderNodeVisitor<LayoutCursor>(l).run();
     // int nodesLayouted = 1;
     // clock_t t0 = clock();
-    while (p.next()) {}
+    // while (p.next()) {}
     // while (p.next()) { nodesLayouted++; }
     // double t = (static_cast<double>(clock()-t0) / CLOCKS_PER_SEC) * 1000.0;
     // double nps = static_cast<double>(nodesLayouted) /
@@ -121,82 +125,80 @@ namespace Gecode { namespace Gist {
     //   << t << " ms. " << nps << " nodes/s." << std::endl;
   }
 
-  void VisualNode::pathUp(void) {
+  void VisualNode::pathUp(const NodeAllocator& na) {
     VisualNode* cur = this;
     while (cur) {
       cur->setOnPath(true);
-      cur = cur->getParent();
+      cur = cur->getParent(na);
     }
   }
 
-  void VisualNode::unPathUp(void) {
+  void VisualNode::unPathUp(const NodeAllocator& na) {
     VisualNode* cur = this;
     while (!cur->isRoot()) {
       cur->setOnPath(false);
-      cur = cur->getParent();
+      cur = cur->getParent(na);
     }
   }
 
   int
-  VisualNode::getPathAlternative(void) {
+  VisualNode::getPathAlternative(const NodeAllocator& na) {
     for (int i=getNumberOfChildren(); i--;) {
-      if (getChild(i)->isOnPath())
+      if (getChild(na,i)->isOnPath())
         return i;
     }
     return -1;
   }
 
   void
-  VisualNode::toggleHidden(void) {
+  VisualNode::toggleHidden(const NodeAllocator& na) {
     setHidden(!isHidden());
-    dirtyUp();
+    dirtyUp(na);
   }
 
   void
-  VisualNode::hideFailed(void) {
-    HideFailedCursor c(this);
-    PreorderNodeVisitor<HideFailedCursor> v(c);
-    while (v.next()) {}
-    dirtyUp();
+  VisualNode::hideFailed(const NodeAllocator& na, bool onlyDirty) {
+    HideFailedCursor c(this,na,onlyDirty);
+    PreorderNodeVisitor<HideFailedCursor>(c).run();
+    dirtyUp(na);
   }
 
   void
-  VisualNode::unhideAll(void) {
-    UnhideAllCursor c(this);
-    PreorderNodeVisitor<UnhideAllCursor> v(c);
-    while (v.next()) {}
-    dirtyUp();
+  VisualNode::unhideAll(const NodeAllocator& na) {
+    UnhideAllCursor c(this,na);
+    PreorderNodeVisitor<UnhideAllCursor>(c).run();
+    dirtyUp(na);
   }
 
   void
-  VisualNode::toggleStop(void) {
+  VisualNode::toggleStop(const NodeAllocator& na) {
     if (getStatus() == STOP)
       setStatus(UNSTOP);
     else if (getStatus() == UNSTOP)
       setStatus(STOP);
-    dirtyUp();
+    dirtyUp(na);
   }
   
   void
-  VisualNode::unstopAll(void) {
-    UnstopAllCursor c(this);
-    PreorderNodeVisitor<UnstopAllCursor> v(c);
-    while (v.next()) {}
-    dirtyUp();
+  VisualNode::unstopAll(const NodeAllocator& na) {
+    UnstopAllCursor c(this,na);
+    PreorderNodeVisitor<UnstopAllCursor>(c).run();
+    dirtyUp(na);
   }
 
   void
-  VisualNode::changedStatus() { dirtyUp(); }
+  VisualNode::changedStatus(const NodeAllocator& na) { dirtyUp(na); }
 
   bool
   VisualNode::containsCoordinateAtDepth(int x, int depth) {
+    BoundingBox box = getShape()->getBoundingBox();
     if (x < box.left ||
         x > box.right ||
-        depth >= shape->depth()) {
+        depth >= getShape()->depth()) {
       return false;
     }
     Extent theExtent;
-    if (shape->getExtentAtDepth(depth, theExtent)) {
+    if (getShape()->getExtentAtDepth(depth, theExtent)) {
       return (theExtent.l <= x && x <= theExtent.r);
     } else {
       return false;
@@ -204,7 +206,7 @@ namespace Gecode { namespace Gist {
   }
 
   VisualNode*
-  VisualNode::findNode(int x, int y) {
+  VisualNode::findNode(const NodeAllocator& na, int x, int y) {
     VisualNode* cur = this;
     int depth = y / Layout::dist_y;
 
@@ -215,7 +217,7 @@ namespace Gecode { namespace Gist {
       VisualNode* oldCur = cur;
       cur = NULL;
       for (unsigned int i=0; i<oldCur->getNumberOfChildren(); i++) {
-        VisualNode* nextChild = oldCur->getChild(i);
+        VisualNode* nextChild = oldCur->getChild(na,i);
         int newX = x - nextChild->getOffset();
         if (nextChild->containsCoordinateAtDepth(newX, depth - 1)) {
           cur = nextChild;
@@ -242,17 +244,20 @@ namespace Gecode { namespace Gist {
   class Layouter {
   public:
     /// Compute distance needed between \a shape1 and \a shape2
-    static int getAlpha(Extent* shape1, int depth1,
-                        Extent* shape2, int depth2);
+    template<class S1, class S2>
+    static int getAlpha(const S1& shape1, int depth1,
+                        const S2& shape2, int depth2);
     /// Merge \a shape1 and \a shape2 into \a result with distance \a alpha
+    template<class S1, class S2>
     static void merge(Extent* result,
-                      Extent* shape1, int depth1,
-                      Extent* shape2, int depth2, int alpha);
+                      const S1& shape1, int depth1,
+                      const S2& shape2, int depth2, int alpha);
   };
 
+  template<class S1, class S2>
   int
-  Layouter::getAlpha(Extent* shape1, int depth1,
-                     Extent* shape2, int depth2) {
+  Layouter::getAlpha(const S1& shape1, int depth1,
+                     const S2& shape2, int depth2) {
     int alpha = Layout::minimalSeparation;
     int extentR = 0;
     int extentL = 0;
@@ -264,10 +269,11 @@ namespace Gecode { namespace Gist {
     return alpha;
   }
 
+  template<class S1, class S2>
   void
   Layouter::merge(Extent* result,
-                  Extent* shape1, int depth1,
-                  Extent* shape2, int depth2, int alpha) {
+                  const S1& shape1, int depth1,
+                  const S2& shape2, int depth2, int alpha) {
     if (depth1 == 0) {
       for (int i=depth2; i--;)
         result[i] = shape2[i];
@@ -332,20 +338,35 @@ namespace Gecode { namespace Gist {
 
   void
   VisualNode::setShape(Shape* s) {
-    Shape::deallocate(shape);
+    if (shape != s)
+      Shape::deallocate(shape);
     shape = s;
-    setBoundingBox(shape->getBoundingBox());
+    shape->computeBoundingBox();
   }
 
   void
-  VisualNode::computeShape(VisualNode* root) {
-    Extent extent(Layout::extent);
+  VisualNode::computeShape(const NodeAllocator& na, VisualNode* root) {
     int numberOfShapes = getNumberOfChildren();
+    Extent extent(Layout::extent);
+
+    int maxDepth = 0;
+    for (int i = numberOfShapes; i--;)
+      maxDepth = std::max(maxDepth, getChild(na,i)->getShape()->depth());
+    Shape* mergedShape;
+    if (getShape() && getShape()->depth() >= maxDepth+1) {
+      mergedShape = getShape();
+      mergedShape->setDepth(maxDepth+1);
+    } else {
+      mergedShape = Shape::allocate(maxDepth+1);
+    }
+
     if (numberOfShapes == 1) {
-      getChild(0)->setOffset(0);
-      Shape* result = Shape::allocate(extent, getChild(0)->getShape());
-      (*result)[1].extend(- extent.l, - extent.r);
-      setShape(result);
+      getChild(na,0)->setOffset(0);
+      const Shape* childShape = getChild(na,0)->getShape();
+      for (int i=childShape->depth(); i--;)
+        (*mergedShape)[i+1] = (*childShape)[i];
+      (*mergedShape)[1].extend(- extent.l, - extent.r);
+      setShape(mergedShape);
     } else {
       // alpha stores the necessary distances between the
       // axes of the shapes in the list: alpha[i].first gives the distance
@@ -361,20 +382,14 @@ namespace Gecode { namespace Gist {
       // distance between the leftmost and the rightmost axis in the list
       int width = 0;
 
-      int maxDepth = 0;
-      for (int i = numberOfShapes; i--;)
-        maxDepth = std::max(maxDepth, getChild(i)->getShape()->depth());
-
       Extent* currentShapeL = r.alloc<Extent>(maxDepth);
-      int ldepth = getChild(0)->getShape()->depth();
+      int ldepth = getChild(na,0)->getShape()->depth();
       for (int i=ldepth; i--;)
-        currentShapeL[i] = (*getChild(0)->getShape())[i];
+        currentShapeL[i] = (*getChild(na,0)->getShape())[i];
 
       // After merging, we can pick the result of either merging left or right
       // Here we chose the result of merging right
-      Shape* mergedShape = Shape::allocate(maxDepth+1);
-      (*mergedShape)[0] = extent;
-      Shape* rShape = getChild(numberOfShapes-1)->getShape();
+      Shape* rShape = getChild(na,numberOfShapes-1)->getShape();
       int rdepth = rShape->depth();
       for (int i=rdepth; i--;)
         (*mergedShape)[i+1] = (*rShape)[i];
@@ -388,25 +403,28 @@ namespace Gecode { namespace Gist {
         // between the *previous* axis and the axis of nextShapeL.
         // This explains the correction.
 
-        Shape* nextShapeL = getChild(i)->getShape();
+        Shape* nextShapeL = getChild(na,i)->getShape();
         int nextAlphaL =
-          Layouter::getAlpha(&currentShapeL[0], ldepth,
-                             &(*nextShapeL)[0], nextShapeL->depth());
-        Layouter::merge(&currentShapeL[0], &currentShapeL[0], ldepth,
-                        &(*nextShapeL)[0], nextShapeL->depth(), nextAlphaL);
+          Layouter::getAlpha<Extent*,Shape>(&currentShapeL[0], ldepth,
+                             *nextShapeL, nextShapeL->depth());
+        Layouter::merge<Extent*,Shape>(&currentShapeL[0],
+                                       &currentShapeL[0], ldepth,
+                                       *nextShapeL, nextShapeL->depth(), 
+                                       nextAlphaL);
         ldepth = std::max(ldepth,nextShapeL->depth());
         alpha[i].first = nextAlphaL - width;
         width = nextAlphaL;
 
         // Merge right-to-left.  Here, a correction of nextAlphaR is
         // not required.
-        Shape* nextShapeR = getChild(numberOfShapes-1-i)->getShape();
+        Shape* nextShapeR = getChild(na,numberOfShapes-1-i)->getShape();
         int nextAlphaR =
-          Layouter::getAlpha(&(*nextShapeR)[0], nextShapeR->depth(),
+          Layouter::getAlpha<Shape,Extent*>(*nextShapeR, nextShapeR->depth(),
                                &currentShapeR[0], rdepth);
-        Layouter::merge(&currentShapeR[0],
-                        &(*nextShapeR)[0], nextShapeR->depth(),
-                        &currentShapeR[0], rdepth, nextAlphaR);
+        Layouter::merge<Shape,Extent*>(&currentShapeR[0],
+                                       *nextShapeR, nextShapeR->depth(),
+                                       &currentShapeR[0], rdepth,
+                                       nextAlphaR);
         rdepth = std::max(rdepth,nextShapeR->depth());
         alpha[numberOfShapes - i].second = nextAlphaR;
       }
@@ -428,10 +446,10 @@ namespace Gecode { namespace Gist {
       // median of the alphaL and alphaR values, as suggested in
       // Kennedy's paper.
       int offset = - halfWidth;
-      getChild(0)->setOffset(offset);
+      getChild(na,0)->setOffset(offset);
       for (int i = 1; i < numberOfShapes; i++) {
         offset += (alpha[i].first + alpha[i].second) / 2;
-        getChild(i)->setOffset(offset);
+        getChild(na,i)->setOffset(offset);
       }
       setShape(mergedShape);
     }
@@ -445,9 +463,7 @@ namespace Gecode { namespace Gist {
       s += sizeof(Shape)+sizeof(Extent)*(shape->depth()-1);
     }
     if (copy)
-      s += copy->allocated();
-    if (workingSpace)
-      s += workingSpace->allocated();
+      s += static_cast<Space*>(Support::funmark(copy))->allocated();
     s += (choice != NULL ? choice->size() : 0);
     return s;
   }
