@@ -7,8 +7,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10364 $
+ *     $Date: 2010-07-28 16:13:53 +0200 (Wed, 28 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11292 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -343,12 +343,13 @@ namespace Gecode { namespace Int { namespace Arithmetic {
 
     }
 
+    Region r(home);
     {
       ViewValues<View> i(x0), j(x0);
       using namespace Iter::Values;
       Positive<ViewValues<View> > p(i);
       Negative<ViewValues<View> > n(j);
-      Minus<Negative<ViewValues<View> > > m(n);
+      Minus<Negative<ViewValues<View> > > m(r,n);
 
       Map<Positive<ViewValues<View> >,ValuesMapSqr,true> sp(p);
       Map<Minus<Negative<ViewValues<View> > >,ValuesMapSqr,true> sm(m);
@@ -361,7 +362,7 @@ namespace Gecode { namespace Int { namespace Arithmetic {
       ViewValues<View> i(x1), j(x1);
       using namespace Iter::Values;
       Map<ViewValues<View>,ValuesMapSqrt,true> si(i), sj(j);
-      Minus<Map<ViewValues<View>,ValuesMapSqrt,true> > mi(si);
+      Minus<Map<ViewValues<View>,ValuesMapSqrt,true> > mi(r,si);
       Union<Minus<Map<ViewValues<View>,ValuesMapSqrt,true> >,
         Map<ViewValues<View>,ValuesMapSqrt,true> > u(mi,sj);
       GECODE_ME_CHECK(x0.inter_v(home,u,false));
