@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2010-04-23 16:53:08 +0200 (Fri, 23 Apr 2010) $ by $Author: tack $
- *     $Revision: 10801 $
+ *     $Date: 2010-10-04 10:01:21 +0200 (Mon, 04 Oct 2010) $ by $Author: schulte $
+ *     $Revision: 11440 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -39,6 +39,15 @@
 
 namespace Gecode {
 
+  IntArgs::IntArgs(int n, int e0, ...) : PrimArgArray<int>(n) {
+    va_list args;
+    va_start(args, e0);
+    a[0] = e0;
+    for (int i = 1; i < n; i++)
+      a[i] = va_arg(args,int);
+    va_end(args);
+  }
+  
   IntVarArray::IntVarArray(Space& home, int n, int min, int max)
     : VarArray<IntVar>(home,n) {
     Int::Limits::check(min,"IntVarArray::IntVarArray");
