@@ -7,8 +7,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2010-07-14 17:46:18 +0200 (Wed, 14 Jul 2010) $ by $Author: schulte $
- *     $Revision: 11192 $
+ *     $Date: 2010-10-04 10:01:21 +0200 (Mon, 04 Oct 2010) $ by $Author: schulte $
+ *     $Revision: 11440 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -48,16 +48,6 @@ namespace Gecode {
   forceinline
   IntArgs::IntArgs(int n) : PrimArgArray<int>(n) {}
   
-  forceinline
-  IntArgs::IntArgs(int n, int e0, ...) : PrimArgArray<int>(n) {
-    va_list args;
-    va_start(args, e0);
-    a[0] = e0;
-    for (int i = 1; i < n; i++)
-      a[i] = va_arg(args,int);
-    va_end(args);
-  }
-  
   forceinline
   IntArgs::IntArgs(const SharedArray<int>& x)
     : PrimArgArray<int>(x.size()) {
