@@ -7,8 +7,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9909 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -130,6 +130,13 @@ namespace Gecode { namespace Int { namespace Bool {
     return ES_OK;
   }
 
+  template<class VX, class VY>
+  forceinline size_t
+  ClauseTrue<VX,VY>::dispose(Space& home) {
+    (void) MixBinaryPropagator<VX,PC_BOOL_VAL,VY,PC_BOOL_VAL>::dispose(home);
+    return sizeof(*this);
+  }
+
   template<class VX, class VY>
   forceinline ExecStatus
   resubscribe(Space& home, Propagator& p,
@@ -140,7 +147,7 @@ namespace Gecode { namespace Int { namespace Bool {
       for (int i=n; i--; )
         if (x[i].one()) {
           x.size(n);
-          return ES_SUBSUMED(p,home);
+          return home.ES_SUBSUMED(p);
         } else if (x[i].zero()) {
           x[i] = x[--n];
         } else {
@@ -169,19 +176,12 @@ namespace Gecode { namespace Int { namespace Bool {
   ExecStatus
   ClauseTrue<VX,VY>::propagate(Space& home, const ModEventDelta&) {
     if (x0.one() || x1.one())
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     GECODE_ES_CHECK(resubscribe(home,*this,x0,x,x1,y));
     GECODE_ES_CHECK(resubscribe(home,*this,x1,y,x0,x));
     return ES_FIX;
   }
 
-  template<class VX, class VY>
-  size_t
-  ClauseTrue<VX,VY>::dispose(Space& home) {
-    (void) MixBinaryPropagator<VX,PC_BOOL_VAL,VY,PC_BOOL_VAL>::dispose(home);
-    return sizeof(*this);
-  }
-
 
   /*
    * Boolean clause propagator (disjunctive)
@@ -306,6 +306,14 @@ namespace Gecode { namespace Int { namespace Bool {
     z.cancel(home,*this,PC_BOOL_VAL);
   }
 
+  template<class VX, class VY>
+  forceinline size_t
+  Clause<VX,VY>::dispose(Space& home) {
+    cancel(home);
+    (void) Propagator::dispose(home);
+    return sizeof(*this);
+  }
+
 
   template<class VX, class VY>
   ExecStatus
@@ -334,18 +342,9 @@ namespace Gecode { namespace Int { namespace Bool {
       c.dispose(home);
     } else {
       // There is exactly one view which is one
-      cancel(home);
       GECODE_ME_CHECK(z.one_none(home));
     }
-    return ES_SUBSUMED(*this,sizeof(*this));
-  }
-
-  template<class VX, class VY>
-  size_t
-  Clause<VX,VY>::dispose(Space& home) {
-    cancel(home);
-    (void) Propagator::dispose(home);
-    return sizeof(*this);
+    return home.ES_SUBSUMED(*this);
   }
 
 }}}
