@@ -7,8 +7,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2010-06-03 13:46:55 +0200 (Thu, 03 Jun 2010) $ by $Author: schulte $
- *     $Revision: 11014 $
+ *     $Date: 2010-09-01 12:02:08 +0200 (Wed, 01 Sep 2010) $ by $Author: schulte $
+ *     $Revision: 11371 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -124,14 +124,15 @@ namespace Gecode { namespace Int { namespace Branch {
   forceinline
   ViewValuesBrancher<ViewSel,View>::
   ViewValuesBrancher(Home home, ViewArray<typename ViewSel::View>& x,
-                     ViewSel& vi_s)
-    : ViewBrancher<ViewSel>(home,x,vi_s) {}
+                     ViewSel& vi_s, BranchFilter bf)
+    : ViewBrancher<ViewSel>(home,x,vi_s,bf) {}
 
   template<class ViewSel, class View>
   void
   ViewValuesBrancher<ViewSel,View>::
-  post(Home home, ViewArray<typename ViewSel::View>& x, ViewSel& vi_s) {
-    (void) new (home) ViewValuesBrancher<ViewSel,View>(home,x,vi_s);
+  post(Home home, ViewArray<typename ViewSel::View>& x, ViewSel& vi_s,
+       BranchFilter bf) {
+    (void) new (home) ViewValuesBrancher<ViewSel,View>(home,x,vi_s,bf);
   }
 
   template<class ViewSel, class View>
