@@ -7,8 +7,8 @@
  *     Christian Schulte, 2006
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-02-02 14:05:18 +0100 (Tue, 02 Feb 2010) $ by $Author: schulte $
+ *     $Revision: 10259 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -63,9 +63,8 @@ namespace Gecode { namespace Int { namespace Channel {
   template<class Info, PropCond pc>
   forceinline size_t
   Base<Info,pc>::dispose(Space& home) {
-    if (!home.failed())
-      for (int i=2*n; i--; )
-        xy[i].view.cancel(home,*this,pc);
+    for (int i=2*n; i--; )
+      xy[i].view.cancel(home,*this,pc);
     (void) Propagator::dispose(home);
     return sizeof(*this);
   }
