@@ -11,8 +11,8 @@
  *     Mikael Lagerkvist, 2006
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -218,7 +218,7 @@ namespace Gecode { namespace Int { namespace Channel {
     } while (!xa.empty());
 
     if (n_na == 0)
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     return shared ? ES_NOFIX : ES_FIX;
   }
 
