@@ -7,8 +7,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2008-09-03 14:14:11 +0200 (Wed, 03 Sep 2008) $ by $Author: tack $
- *     $Revision: 7787 $
+ *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
+ *     $Revision: 9878 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -44,98 +44,98 @@ namespace Gecode { namespace Int { namespace Count {
    *
    */
 
-  template <class VX>
+  template<class VX>
   forceinline RelTest
   holds(VX x, ConstIntView y) {
     return rtest_eq_dom(x,y.val());
   }
-  template <class VX>
+  template<class VX>
   forceinline RelTest
   holds(VX x, ZeroIntView) {
     return rtest_eq_dom(x,0);
   }
-  template <class VX>
+  template<class VX>
   forceinline RelTest
   holds(VX x, VX y) {
     return rtest_eq_dom(x,y);
   }
-  template <class VX>
+  template<class VX>
   forceinline bool
-  post_true(Space& home, VX x, ConstIntView y) {
+  post_true(Home home, VX x, ConstIntView y) {
     return me_failed(x.eq(home,y.val()));
   }
-  template <class VX>
+  template<class VX>
   forceinline bool
-  post_true(Space& home, VX x, ZeroIntView) {
+  post_true(Home home, VX x, ZeroIntView) {
     return me_failed(x.eq(home,0));
   }
-  template <class VX>
+  template<class VX>
   forceinline bool
-  post_true(Space& home, ViewArray<VX>& x, ConstIntView y) {
+  post_true(Home home, ViewArray<VX>& x, ConstIntView y) {
     for (int i = x.size(); i--; )
       if (me_failed(x[i].eq(home,y.val())))
         return true;
     return false;
   }
-  template <class VX>
+  template<class VX>
   forceinline bool
-  post_true(Space& home, ViewArray<VX>& x, ZeroIntView) {
+  post_true(Home home, ViewArray<VX>& x, ZeroIntView) {
     for (int i = x.size(); i--; )
       if (me_failed(x[i].eq(home,0)))
         return true;
     return false;
   }
-  template <class VX>
+  template<class VX>
   forceinline bool
-  post_false(Space& home, VX x, ConstIntView y) {
+  post_false(Home home, VX x, ConstIntView y) {
     return me_failed(x.nq(home,y.val()));
   }
-  template <class VX>
+  template<class VX>
   forceinline bool
-  post_false(Space& home, VX x, ZeroIntView) {
+  post_false(Home home, VX x, ZeroIntView) {
     return me_failed(x.nq(home,0));
   }
-  template <class VX>
+  template<class VX>
   forceinline bool
-  post_false(Space& home, ViewArray<VX>& x, ConstIntView y) {
+  post_false(Home home, ViewArray<VX>& x, ConstIntView y) {
     for (int i = x.size(); i--; )
       if (me_failed(x[i].nq(home,y.val())))
         return true;
     return false;;
   }
-  template <class VX>
+  template<class VX>
   forceinline bool
-  post_false(Space& home, ViewArray<VX>& x, ZeroIntView) {
+  post_false(Home home, ViewArray<VX>& x, ZeroIntView) {
     for (int i = x.size(); i--; )
       if (me_failed(x[i].nq(home,0)))
         return true;
     return false;;
   }
-  template <class VX>
+  template<class VX>
   forceinline bool
-  post_true(Space& home, ViewArray<VX>& x, VX y) {
+  post_true(Home home, ViewArray<VX>& x, VX y) {
     ViewArray<VX> z(home,x.size()+1);
     z[x.size()] = y;
     for (int i = x.size(); i--; )
       z[i] = x[i];
     return Rel::NaryEqDom<VX>::post(home,z) == ES_FAILED;
   }
-  template <class VX>
+  template<class VX>
   forceinline bool
-  post_true(Space& home, VX x, VX y) {
+  post_true(Home home, VX x, VX y) {
     return Rel::EqDom<VX,VX>::post(home,x,y) == ES_FAILED;
   }
-  template <class VX>
+  template<class VX>
   forceinline bool
-  post_false(Space& home, ViewArray<VX>& x, VX y) {
+  post_false(Home home, ViewArray<VX>& x, VX y) {
     for (int i = x.size(); i--; )
       if (Rel::Nq<VX>::post(home,x[i],y) == ES_FAILED)
         return true;
     return false;
   }
-  template <class VX>
+  template<class VX>
   forceinline bool
-  post_false(Space& home, VX x, VX y) {
+  post_false(Home home, VX x, VX y) {
     return Rel::Nq<VX>::post(home,x,y) == ES_FAILED;
   }
 
