@@ -7,8 +7,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -166,7 +166,7 @@ namespace Gecode { namespace Int { namespace Distinct {
   ExecStatus
   Val<View>::propagate(Space& home, const ModEventDelta&) {
     GECODE_ES_CHECK((prop_val<View,true>(home,x)));
-    return (x.size() < 2) ? ES_SUBSUMED(*this,home) : ES_FIX;
+    return (x.size() < 2) ? home.ES_SUBSUMED(*this) : ES_FIX;
   }
 
   template<class View>
