@@ -11,8 +11,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10364 $
+ *     $Date: 2010-09-03 16:36:31 +0200 (Fri, 03 Sep 2010) $ by $Author: schulte $
+ *     $Revision: 11390 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -546,7 +546,7 @@ namespace Gecode { namespace Int { namespace Element {
     ViewRanges<VA>* i_view = r.alloc<ViewRanges<VA> >(iv.size());
     for (int i = iv.size(); i--; )
       i_view[i].init(iv[i].view);
-    Iter::Ranges::NaryUnion<ViewRanges<VA> > i_val(i_view, iv.size());
+    Iter::Ranges::NaryUnion<ViewRanges<VA> > i_val(r, i_view, iv.size());
     ModEvent me = x1.inter_r(home,i_val);
     r.free<ViewRanges<VA> >(i_view,iv.size());
     GECODE_ME_CHECK(me);
