@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2010-04-06 16:35:59 +0200 (Tue, 06 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10651 $
+ *     $Date: 2010-07-14 17:46:18 +0200 (Wed, 14 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11192 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -40,6 +40,40 @@
 
 namespace Gecode { namespace Int { namespace Extensional {
 
+  /**
+   * \brief Traits class for variables
+   *
+   * Each variable must specialize this traits class and add a \code
+   * typedef \endcode for the view \a View corresponding to this variable.
+   */
+  template<class Var>
+  class VarTraits {};
+
+  /**
+   * \brief Traits class for variables
+   *
+   * This class specializes the VarTraits for integer variables.
+   */
+  template<>
+  class VarTraits<IntVar> {
+  public:
+    /// The variable type of an IntView
+    typedef Int::IntView View;
+  };
+
+  /**
+   * \brief Traits class for variables
+   *
+   * This class specializes the VarTraits for Boolean variables.
+   */
+  template<>
+  class VarTraits<BoolVar> {
+  public:
+    /// The variable type of an IntView
+    typedef Int::BoolView View;
+  };
+
+
   /*
    * States
    */
@@ -244,7 +278,7 @@ namespace Gecode { namespace Int { namespace Extensional {
 
     // Allocate temporary memory for all possible states
     State* states = r.alloc<State>(max_states*(n+1));
-    for (int i=max_states*(n+1); i--; )
+    for (int i=static_cast<int>(max_states)*(n+1); i--; )
       states[i].init();
     for (int i=n+1; i--; )
       layers[i].states = states + i*max_states;
@@ -287,8 +321,8 @@ namespace Gecode { namespace Int { namespace Extensional {
 
     // Mark final states as reachable
     for (int s=dfa.final_fst(); s<dfa.final_lst(); s++)
-      if (o_state(n-1,s).i_deg != 0)
-        o_state(n-1,s).o_deg = 1;
+      if (o_state(n-1,static_cast<StateIdx>(s)).i_deg != 0)
+        o_state(n-1,static_cast<StateIdx>(s)).o_deg = 1;
 
     // Backward pass: prune all transitions that do not lead to final state
     for (int i=n; i--; ) {
@@ -412,7 +446,7 @@ namespace Gecode { namespace Int { namespace Extensional {
     // Check whether state information has already been created
     if (layers[0].states == NULL) {
       State* states = home.alloc<State>(n_states);
-      for (int i=n_states; i--; )
+      for (unsigned int i=n_states; i--; )
         states[i].init();
       layers[n].states = states;
       states += layers[n].n_states;
@@ -658,7 +692,7 @@ namespace Gecode { namespace Int { namespace Extensional {
     assert(x.size() > 0);
     for (int i=x.size(); i--; ) {
       DFA::Symbols s(dfa);
-      typename VarViewTraits<Var>::View xi(x[i]);
+      typename VarTraits<Var>::View xi(x[i]);
       GECODE_ME_CHECK(xi.inter_v(home,s,false));
     }
     LayeredGraph<View,Val,Degree,StateIdx>* p =
@@ -835,15 +869,15 @@ namespace Gecode { namespace Int { namespace Extensional {
         switch (t_degree) {
         case Gecode::Support::IT_CHAR:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,short int,unsigned char,unsigned char>
+            <typename VarTraits<Var>::View,short int,unsigned char,unsigned char>
             ::post(home,x,dfa);
         case Gecode::Support::IT_SHRT:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,short int,unsigned short int,unsigned char>
+            <typename VarTraits<Var>::View,short int,unsigned short int,unsigned char>
             ::post(home,x,dfa);
         case Gecode::Support::IT_INT:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,short int,unsigned int,unsigned char>
+            <typename VarTraits<Var>::View,short int,unsigned int,unsigned char>
             ::post(home,x,dfa);
         default: GECODE_NEVER;
         }
@@ -852,15 +886,15 @@ namespace Gecode { namespace Int { namespace Extensional {
         switch (t_degree) {
         case Gecode::Support::IT_CHAR:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,short int,unsigned char,unsigned short int>
+            <typename VarTraits<Var>::View,short int,unsigned char,unsigned short int>
             ::post(home,x,dfa);
         case Gecode::Support::IT_SHRT:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,short int,unsigned short int,unsigned short int>
+            <typename VarTraits<Var>::View,short int,unsigned short int,unsigned short int>
             ::post(home,x,dfa);
         case Gecode::Support::IT_INT:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,short int,unsigned int,unsigned short int>
+            <typename VarTraits<Var>::View,short int,unsigned int,unsigned short int>
             ::post(home,x,dfa);
         default: GECODE_NEVER;
         }
@@ -869,15 +903,15 @@ namespace Gecode { namespace Int { namespace Extensional {
         switch (t_degree) {
         case Gecode::Support::IT_CHAR:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,short int,unsigned char,unsigned int>
+            <typename VarTraits<Var>::View,short int,unsigned char,unsigned int>
             ::post(home,x,dfa);
         case Gecode::Support::IT_SHRT:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,short int,unsigned short int,unsigned int>
+            <typename VarTraits<Var>::View,short int,unsigned short int,unsigned int>
             ::post(home,x,dfa);
         case Gecode::Support::IT_INT:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,short int,unsigned int,unsigned int>
+            <typename VarTraits<Var>::View,short int,unsigned int,unsigned int>
             ::post(home,x,dfa);
         default: GECODE_NEVER;
         }
@@ -891,15 +925,15 @@ namespace Gecode { namespace Int { namespace Extensional {
         switch (t_degree) {
         case Gecode::Support::IT_CHAR:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,int,unsigned char,unsigned char>
+            <typename VarTraits<Var>::View,int,unsigned char,unsigned char>
             ::post(home,x,dfa);
         case Gecode::Support::IT_SHRT:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,int,unsigned short int,unsigned char>
+            <typename VarTraits<Var>::View,int,unsigned short int,unsigned char>
             ::post(home,x,dfa);
         case Gecode::Support::IT_INT:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,int,unsigned int,unsigned char>
+            <typename VarTraits<Var>::View,int,unsigned int,unsigned char>
             ::post(home,x,dfa);
         default: GECODE_NEVER;
         }
@@ -908,15 +942,15 @@ namespace Gecode { namespace Int { namespace Extensional {
         switch (t_degree) {
         case Gecode::Support::IT_CHAR:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,int,unsigned char,unsigned short int>
+            <typename VarTraits<Var>::View,int,unsigned char,unsigned short int>
             ::post(home,x,dfa);
         case Gecode::Support::IT_SHRT:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,int,unsigned short int,unsigned short int>
+            <typename VarTraits<Var>::View,int,unsigned short int,unsigned short int>
             ::post(home,x,dfa);
         case Gecode::Support::IT_INT:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,int,unsigned int,unsigned short int>
+            <typename VarTraits<Var>::View,int,unsigned int,unsigned short int>
             ::post(home,x,dfa);
         default: GECODE_NEVER;
         }
@@ -925,15 +959,15 @@ namespace Gecode { namespace Int { namespace Extensional {
         switch (t_degree) {
         case Gecode::Support::IT_CHAR:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,int,unsigned char,unsigned int>
+            <typename VarTraits<Var>::View,int,unsigned char,unsigned int>
             ::post(home,x,dfa);
         case Gecode::Support::IT_SHRT:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,int,unsigned short int,unsigned int>
+            <typename VarTraits<Var>::View,int,unsigned short int,unsigned int>
             ::post(home,x,dfa);
         case Gecode::Support::IT_INT:
           return Extensional::LayeredGraph
-            <typename VarViewTraits<Var>::View,int,unsigned int,unsigned int>
+            <typename VarTraits<Var>::View,int,unsigned int,unsigned int>
             ::post(home,x,dfa);
         default: GECODE_NEVER;
         }
