@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:40:32 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10365 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -112,13 +112,13 @@ namespace Gecode {
     IntView v(y);
     switch (r) {
     case IRT_EQ:
-      GECODE_ME_FAIL(home,v.gq(home,min)); GECODE_ME_FAIL(home,v.lq(home,max));
+      GECODE_ME_FAIL(v.gq(home,min)); GECODE_ME_FAIL(v.lq(home,max));
       break;
     case IRT_GQ:
-      GECODE_ME_FAIL(home,v.lq(home,max));
+      GECODE_ME_FAIL(v.lq(home,max));
       break;
     case IRT_LQ:
-      GECODE_ME_FAIL(home,v.gq(home,min));
+      GECODE_ME_FAIL(v.gq(home,min));
       break;
     default: ;
     }
@@ -158,13 +158,13 @@ namespace Gecode {
     IntView v(y);
     switch (r) {
     case IRT_EQ:
-      GECODE_ME_FAIL(home,v.gq(home,min)); GECODE_ME_FAIL(home,v.lq(home,max));
+      GECODE_ME_FAIL(v.gq(home,min)); GECODE_ME_FAIL(v.lq(home,max));
       break;
     case IRT_GQ:
-      GECODE_ME_FAIL(home,v.lq(home,max));
+      GECODE_ME_FAIL(v.lq(home,max));
       break;
     case IRT_LQ:
-      GECODE_ME_FAIL(home,v.gq(home,min));
+      GECODE_ME_FAIL(v.gq(home,min));
       break;
     default: ;
     }
