@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2009-01-20 23:44:27 +0100 (Tue, 20 Jan 2009) $ by $Author: schulte $
- *     $Revision: 8082 $
+ *     $Date: 2010-07-13 22:35:02 +0200 (Tue, 13 Jul 2010) $ by $Author: tack $
+ *     $Revision: 11183 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -55,7 +55,11 @@ namespace Gecode { namespace Int { namespace Linear {
       }
     if (min < Limits::min)
       min = Limits::min;
+    if (min > Limits::max)
+      min = Limits::max;
     l = static_cast<int>(min);
+    if (max < Limits::min)
+      max = Limits::min;
     if (max > Limits::max)
       max = Limits::max;
     u = static_cast<int>(max);
