@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10364 $
+ *     $Date: 2010-07-28 16:13:53 +0200 (Wed, 28 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11292 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -310,7 +310,8 @@ namespace Gecode { namespace Int { namespace Rel {
       i_x[i] = i_xi;
     }
     Iter::Ranges::NaryInter<ViewRanges<View> > r(i_x,n);
-    Iter::Ranges::Cache<Iter::Ranges::NaryInter<ViewRanges<View> > > rc(r);
+    Iter::Ranges::Cache<Iter::Ranges::NaryInter<ViewRanges<View> > > 
+      rc(re,r);
 
     if (!rc())
       return ES_FAILED;
