@@ -7,8 +7,8 @@
  *     Patrick Pekczynski, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:40:32 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10365 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -52,7 +52,7 @@ namespace Gecode {
 
     ViewArray<IntView> x0(home,x), y0(home,y), z0(home,z);
 
-    GECODE_ES_FAIL(home,
+    GECODE_ES_FAIL(
                    (Sorted::Sorted<IntView,true>::post(home,x0,y0,z0)));
   }
 
@@ -69,7 +69,7 @@ namespace Gecode {
 
     ViewArray<IntView> x0(home,x), y0(home,y), z0(home,0);
 
-    GECODE_ES_FAIL(home,
+    GECODE_ES_FAIL(
                    (Sorted::Sorted<IntView,false>::post(home,x0,y0,z0)));
   }
 
