@@ -7,8 +7,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2010-06-29 10:39:13 +0200 (Tue, 29 Jun 2010) $ by $Author: schulte $
- *     $Revision: 11118 $
+ *     $Date: 2010-10-06 22:42:28 +0200 (Wed, 06 Oct 2010) $ by $Author: schulte $
+ *     $Revision: 11464 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -132,9 +132,9 @@ namespace Gecode { namespace Int {
    * \brief Integer view for integer variables
    * \ingroup TaskActorIntView
    */
-  class IntView : public VarImpView<IntVarImp> {
+  class IntView : public VarImpView<IntVar> {
   protected:
-    using VarImpView<IntVarImp>::x;
+    using VarImpView<IntVar>::x;
   public:
     /// \name Constructors and initialization
     //@{
@@ -437,6 +437,8 @@ namespace Gecode { namespace Int {
     //@{
     /// Return offset
     int offset(void) const;
+    /// Change offset to \a n
+    void offset(int n);
     /// Return minimum of domain
     int min(void) const;
     /// Return maximum of domain
@@ -1037,9 +1039,9 @@ namespace Gecode { namespace Int {
    * Provides convenient and efficient operations for Boolean views.
    * \ingroup TaskActorIntView
    */
-  class BoolView : public VarImpView<BoolVarImp> {
+  class BoolView : public VarImpView<BoolVar> {
   protected:
-    using VarImpView<BoolVarImp>::x;
+    using VarImpView<BoolVar>::x;
   public:
     /// \name Constructors and initialization
     //@{
