@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2010-06-29 10:39:13 +0200 (Tue, 29 Jun 2010) $ by $Author: schulte $
- *     $Revision: 11118 $
+ *     $Date: 2010-10-06 22:42:28 +0200 (Wed, 06 Oct 2010) $ by $Author: schulte $
+ *     $Revision: 11464 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -56,6 +56,10 @@ namespace Gecode { namespace Int {
   OffsetView::offset(void) const {
     return c;
   }
+  forceinline void
+  OffsetView::offset(int n) {
+    c = n;
+  }
   forceinline int
   OffsetView::min(void) const {
     return x.min()+c;
