@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-07-28 17:35:33 +0200 (Wed, 28 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11294 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -46,11 +46,6 @@ namespace Gecode { namespace Iter { namespace Ranges {
    */
   template<class I, class J>
   class Inter : public MinMax {
-  private:
-    /// Check that \a I is a range iterator;
-    IsRangeIter<I> _checkI;
-    /// Check that \a J is a range iterator;
-    IsRangeIter<J> _checkJ;
   protected:
     /// First iterator
     I i;
@@ -82,9 +77,6 @@ namespace Gecode { namespace Iter { namespace Ranges {
    */
   template<class I>
   class NaryInter : public MinMax {
-  private:
-    /// Check that \a I is a range iterator;
-    IsRangeIter<I> _checkI;
   protected:
     /// Array of iterators
     I* is;
