@@ -4,13 +4,17 @@
  *     Christian Schulte <schulte@gecode.org>
  *     Guido Tack <tack@gecode.org>
  *
+ *  Contributing authors:
+ *     Gregory Crosswhite <gcross@phys.washington.edu>
+ *
  *  Copyright:
+ *     Gregory Crosswhite, 2011
  *     Christian Schulte, 2003
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2010-06-03 13:46:55 +0200 (Thu, 03 Jun 2010) $ by $Author: schulte $
- *     $Revision: 11014 $
+ *     $Date: 2011-01-27 13:03:05 +0100 (Thu, 27 Jan 2011) $ by $Author: schulte $
+ *     $Revision: 11570 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -39,6 +43,7 @@
 
 #include <cstdarg>
 #include <iostream>
+#include <iterator>
 #include <sstream>
 
 namespace Gecode {
@@ -84,6 +89,29 @@ namespace Gecode {
     /// Array of variables
     Var* x;
   public:
+    /// \name Associated types
+    //@{
+    /// Type of the variable stored in this array
+    typedef Var value_type;
+    /// Type of a reference to the value type
+    typedef Var& reference;
+    /// Type of a constant reference to the value type
+    typedef const Var& const_reference;
+    /// Type of a pointer to the value type
+    typedef Var* pointer;
+    /// Type of a read-only pointer to the value type
+    typedef const Var* const_pointer;
+    /// Type of the iterator used to iterate through this array's elements
+    typedef Var* iterator;
+    /// Type of the iterator used to iterate read-only through this array's elements
+    typedef const Var* const_iterator;
+    /// Type of the iterator used to iterate backwards through this array's elements
+    typedef std::reverse_iterator<Var*> reverse_iterator;
+    /// Type of the iterator used to iterate backwards and read-only through this array's elements
+    typedef std::reverse_iterator<const Var*> const_reverse_iterator;
+    //@}
+
+    //@{
     /// \name Constructors and initialization
     //@{
     /// Default constructor (array of size 0)
@@ -119,6 +147,26 @@ namespace Gecode {
     slice(int start, int inc=1, int n=-1);
     //@}
 
+    /// \name Array iteration
+    //@{
+    /// Return an iterator at the beginning of the array
+    iterator begin(void);
+    /// Return a read-only iterator at the beginning of the array
+    const_iterator begin(void) const;
+    /// Return an iterator past the end of the array
+    iterator end(void);
+    /// Return a read-only iterator past the end of the array
+    const_iterator end(void) const;
+    /// Return a reverse iterator at the end of the array
+    reverse_iterator rbegin(void);
+    /// Return a reverse and read-only iterator at the end of the array
+    const_reverse_iterator rbegin(void) const;
+    /// Return a reverse iterator past the beginning of the array
+    reverse_iterator rend(void);
+    /// Return a reverse and read-only iterator past the beginning of the array
+    const_reverse_iterator rend(void) const;
+    //@}
+
     /// Test if all variables are assigned
     bool assigned(void) const;
 
@@ -197,6 +245,28 @@ namespace Gecode {
     /// Sort \a n views \a x according to \a ViewLess
     static void sort(View* x, int n);
   public:
+    /// \name Associated types
+    //@{
+    /// Type of the view stored in this array
+    typedef View value_type;
+    /// Type of a reference to the value type
+    typedef View& reference;
+    /// Type of a constant reference to the value type
+    typedef const View& const_reference;
+    /// Type of a pointer to the value type
+    typedef View* pointer;
+    /// Type of a read-only pointer to the value type
+    typedef const View* const_pointer;
+    /// Type of the iterator used to iterate through this array's elements
+    typedef View* iterator;
+    /// Type of the iterator used to iterate read-only through this array's elements
+    typedef const View* const_iterator;
+    /// Type of the iterator used to iterate backwards through this array's elements
+    typedef std::reverse_iterator<View*> reverse_iterator;
+    /// Type of the iterator used to iterate backwards and read-only through this array's elements
+    typedef std::reverse_iterator<const View*> const_reverse_iterator;
+    //@}
+
     /// \name Constructors and initialization
     //@{
     /// Default constructor (array of size 0)
@@ -245,6 +315,26 @@ namespace Gecode {
     const View& operator [](int i) const;
     //@}
 
+    /// \name Array iteration
+    //@{
+    /// Return an iterator at the beginning of the array
+    iterator begin(void);
+    /// Return a read-only iterator at the beginning of the array
+    const_iterator begin(void) const;
+    /// Return an iterator past the end of the array
+    iterator end(void);
+    /// Return a read-only iterator past the end of the array
+    const_iterator end(void) const;
+    /// Return a reverse iterator at the end of the array
+    reverse_iterator rbegin(void);
+    /// Return a reverse and read-only iterator at the end of the array
+    const_reverse_iterator rbegin(void) const;
+    /// Return a reverse iterator past the beginning of the array
+    reverse_iterator rend(void);
+    /// Return a reverse and read-only iterator past the beginning of the array
+    const_reverse_iterator rend(void) const;
+    //@}
+
     /// \name Dependencies
     //@{
     /**
@@ -441,6 +531,28 @@ namespace Gecode {
     template<class A>
     A slice(int start, int inc=1, int n=-1);
   public:
+    /// \name Associated types
+    //@{
+    /// Type of the view stored in this array
+    typedef T value_type;
+    /// Type of a reference to the value type
+    typedef T& reference;
+    /// Type of a constant reference to the value type
+    typedef const T& const_reference;
+    /// Type of a pointer to the value type
+    typedef T* pointer;
+    /// Type of a read-only pointer to the value type
+    typedef const T* const_pointer;
+    /// Type of the iterator used to iterate through this array's elements
+    typedef T* iterator;
+    /// Type of the iterator used to iterate read-only through this array's elements
+    typedef const T* const_iterator;
+    /// Type of the iterator used to iterate backwards through this array's elements
+    typedef std::reverse_iterator<T*> reverse_iterator;
+    /// Type of the iterator used to iterate backwards and read-only through this array's elements
+    typedef std::reverse_iterator<const T*> const_reverse_iterator;
+    //@}
+
     /// \name Constructors and initialization
     //@{
     /// Allocate empty array
@@ -467,6 +579,26 @@ namespace Gecode {
     const T& operator [](int i) const;
     //@}
 
+    /// \name Array iteration
+    //@{
+    /// Return an iterator at the beginning of the array
+    iterator begin(void);
+    /// Return a read-only iterator at the beginning of the array
+    const_iterator begin(void) const;
+    /// Return an iterator past the end of the array
+    iterator end(void);
+    /// Return a read-only iterator past the end of the array
+    const_iterator end(void) const;
+    /// Return a reverse iterator at the end of the array
+    reverse_iterator rbegin(void);
+    /// Return a reverse and read-only iterator at the end of the array
+    const_reverse_iterator rbegin(void) const;
+    /// Return a reverse iterator past the beginning of the array
+    reverse_iterator rend(void);
+    /// Return a reverse and read-only iterator past the beginning of the array
+    const_reverse_iterator rend(void) const;
+    //@}
+
     /// \name Destructor
     //@{
     /// Destructor
@@ -847,6 +979,54 @@ namespace Gecode {
     return r;
   }
 
+  template<class Var>
+  forceinline typename VarArray<Var>::iterator
+  VarArray<Var>::begin(void) {
+    return x;
+  }
+
+  template<class Var>
+  forceinline typename VarArray<Var>::const_iterator
+  VarArray<Var>::begin(void) const {
+    return x;
+  }
+
+  template<class Var>
+  forceinline typename VarArray<Var>::iterator
+  VarArray<Var>::end(void) {
+    return x+n;
+  }
+
+  template<class Var>
+  forceinline typename VarArray<Var>::const_iterator
+  VarArray<Var>::end(void) const {
+    return x+n;
+  }
+
+  template<class Var>
+  forceinline typename VarArray<Var>::reverse_iterator
+  VarArray<Var>::rbegin(void) {
+    return reverse_iterator(x+n);
+  }
+
+  template<class Var>
+  forceinline typename VarArray<Var>::const_reverse_iterator
+  VarArray<Var>::rbegin(void) const {
+    return const_reverse_iterator(x+n);
+  }
+
+  template<class Var>
+  forceinline typename VarArray<Var>::reverse_iterator
+  VarArray<Var>::rend(void) {
+    return reverse_iterator(x);
+  }
+
+  template<class Var>
+  forceinline typename VarArray<Var>::const_reverse_iterator
+  VarArray<Var>::rend(void) const {
+    return const_reverse_iterator(x);
+  }
+
   template<class Var>
   forceinline void
   VarArray<Var>::update(Space& home, bool share, VarArray<Var>& a) {
@@ -999,6 +1179,54 @@ namespace Gecode {
     return x[i];
   }
 
+  template<class View>
+  forceinline typename ViewArray<View>::iterator
+  ViewArray<View>::begin(void) {
+    return x;
+  }
+
+  template<class View>
+  forceinline typename ViewArray<View>::const_iterator
+  ViewArray<View>::begin(void) const {
+    return x;
+  }
+
+  template<class View>
+  forceinline typename ViewArray<View>::iterator
+  ViewArray<View>::end(void) {
+    return x+n;
+  }
+
+  template<class View>
+  forceinline typename ViewArray<View>::const_iterator
+  ViewArray<View>::end(void) const {
+    return x+n;
+  }
+
+  template<class View>
+  forceinline typename ViewArray<View>::reverse_iterator
+  ViewArray<View>::rbegin(void) {
+    return reverse_iterator(x+n);
+  }
+
+  template<class View>
+  forceinline typename ViewArray<View>::const_reverse_iterator
+  ViewArray<View>::rbegin(void) const {
+    return const_reverse_iterator(x+n);
+  }
+
+  template<class View>
+  forceinline typename ViewArray<View>::reverse_iterator
+  ViewArray<View>::rend(void) {
+    return reverse_iterator(x);
+  }
+
+  template<class View>
+  forceinline typename ViewArray<View>::const_reverse_iterator
+  ViewArray<View>::rend(void) const {
+    return const_reverse_iterator(x);
+  }
+
   template<class View>
   forceinline void
   ViewArray<View>::move_fst(int i) {
@@ -1384,6 +1612,54 @@ namespace Gecode {
     return a[i];
   }
 
+  template<class T>
+  forceinline typename ArgArrayBase<T>::iterator
+  ArgArrayBase<T>::begin(void) {
+    return a;
+  }
+
+  template<class T>
+  forceinline typename ArgArrayBase<T>::const_iterator
+  ArgArrayBase<T>::begin(void) const {
+    return a;
+  }
+
+  template<class T>
+  forceinline typename ArgArrayBase<T>::iterator
+  ArgArrayBase<T>::end(void) {
+    return a+n;
+  }
+
+  template<class T>
+  forceinline typename ArgArrayBase<T>::const_iterator
+  ArgArrayBase<T>::end(void) const {
+    return a+n;
+  }
+
+  template<class T>
+  forceinline typename ArgArrayBase<T>::reverse_iterator
+  ArgArrayBase<T>::rbegin(void) {
+    return reverse_iterator(a+n);
+  }
+
+  template<class T>
+  forceinline typename ArgArrayBase<T>::const_reverse_iterator
+  ArgArrayBase<T>::rbegin(void) const {
+    return const_reverse_iterator(a+n);
+  }
+
+  template<class T>
+  forceinline typename ArgArrayBase<T>::reverse_iterator
+  ArgArrayBase<T>::rend(void) {
+    return reverse_iterator(a);
+  }
+
+  template<class T>
+  forceinline typename ArgArrayBase<T>::const_reverse_iterator
+  ArgArrayBase<T>::rend(void) const {
+    return const_reverse_iterator(a);
+  }
+
   template<class T> template<class A>
   A
   ArgArrayBase<T>::slice(int start, int inc, int maxN) {
