@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2010-07-16 10:51:05 +0200 (Fri, 16 Jul 2010) $ by $Author: tack $
- *     $Revision: 11208 $
+ *     $Date: 2011-01-21 16:01:14 +0100 (Fri, 21 Jan 2011) $ by $Author: schulte $
+ *     $Revision: 11553 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -58,6 +58,86 @@ namespace Gecode {
   }
 
 
+  BoolExpr::BoolExpr(const BoolVar& x) : n(new Node) {
+    n->same = 1;
+    n->t    = NT_VAR;
+    n->l    = NULL;
+    n->r    = NULL;
+    n->x    = x;
+    n->m    = NULL;
+  }
+
+  BoolExpr::BoolExpr(const BoolExpr& l, NodeType t, const BoolExpr& r)
+    : n(new Node) {
+    int ls = ((l.n->t == t) || (l.n->t == NT_VAR)) ? l.n->same : 1;
+    int rs = ((r.n->t == t) || (r.n->t == NT_VAR)) ? r.n->same : 1;
+    n->same = ls+rs;
+    n->t    = t;
+    n->l    = l.n;
+    n->l->use++;
+    n->r    = r.n;
+    n->r->use++;
+    n->m    = NULL;
+  }
+
+  BoolExpr::BoolExpr(const BoolExpr& l, NodeType t) {
+    (void) t;
+    assert(t == NT_NOT);
+    if (l.n->t == NT_NOT) {
+      n = l.n->l;
+      n->use++;
+    } else {
+      n = new Node;
+      n->same = 1;
+      n->t    = NT_NOT;
+      n->l    = l.n;
+      n->l->use++;
+      n->r    = NULL;
+      n->m    = NULL;
+    }
+  }
+
+  BoolExpr::BoolExpr(const LinRel& rl)
+    : n(new Node) {
+    n->same = 1;
+    n->t    = NT_RLIN;
+    n->l    = NULL;
+    n->r    = NULL;
+    n->rl   = rl;
+    n->m    = NULL;
+  }
+
+#ifdef GECODE_HAS_SET_VARS
+  BoolExpr::BoolExpr(const SetRel& rs)
+    : n(new Node) {
+    n->same = 1;
+    n->t    = NT_RSET;
+    n->l    = NULL;
+    n->r    = NULL;
+    n->rs   = rs;
+    n->m    = NULL;
+  }
+
+  BoolExpr::BoolExpr(const SetCmpRel& rs)
+    : n(new Node) {
+    n->same = 1;
+    n->t    = NT_RSET;
+    n->l    = NULL;
+    n->r    = NULL;
+    n->rs   = rs;
+    n->m    = NULL;
+  }
+#endif
+
+  BoolExpr::BoolExpr(BoolExpr::MiscExpr* m)
+    : n(new Node) {
+    n->same = 1;
+    n->t    = NT_MISC;
+    n->l    = NULL;
+    n->r    = NULL;
+    n->m    = m;
+  }
+
   const BoolExpr&
   BoolExpr::operator =(const BoolExpr& e) {
     if (this != &e) {
@@ -69,6 +149,8 @@ namespace Gecode {
     return *this;
   }
 
+  BoolExpr::MiscExpr::~MiscExpr(void) {}
+
   BoolExpr::~BoolExpr(void) {
     if (n->decrement())
       delete n;
@@ -107,6 +189,9 @@ namespace Gecode {
       u.a.x->rs.post(home, b, !u.a.neg);
       break;
 #endif
+    case NT_MISC:
+      u.a.x->m->post(home, b, !u.a.neg, icl);
+      break;
     case NT_AND:
       {
         BoolVarArgs bp(p), bn(n);
@@ -179,6 +264,13 @@ namespace Gecode {
         }
         break;
 #endif
+      case NT_MISC:
+        {
+          BoolVar b(home,0,1);
+          u.a.x->m->post(home, b, !u.a.neg, icl);
+          bp[ip++]=b;
+        }
+        break;      
       default:
         bp[ip++] = expr(home, icl);
         break;
@@ -203,6 +295,12 @@ namespace Gecode {
       u.a.x->rs.post(home, !u.a.neg);
       break;
 #endif
+    case NT_MISC:
+      {
+        BoolVar b(home,!u.a.neg,!u.a.neg);
+        u.a.x->m->post(home, b, false, icl);
+      }
+      break;
     case NT_AND:
       u.b.l->rel(home, icl);
       u.b.r->rel(home, icl);
@@ -254,7 +352,7 @@ namespace Gecode {
   BoolExpr::NNF*
   BoolExpr::NNF::nnf(Region& r, Node* n, bool neg) {
     switch (n->t) {
-    case NT_VAR: case NT_RLIN:
+    case NT_VAR: case NT_RLIN: case NT_MISC:
 #ifdef GECODE_HAS_SET_VARS
     case NT_RSET:
 #endif
@@ -346,7 +444,6 @@ namespace Gecode {
     return BoolExpr(BoolExpr(r,BoolExpr::NT_NOT),
                     BoolExpr::NT_OR,l);
   }
-
   /*
    * Posting Boolean expressions and relations
    *
@@ -365,6 +462,59 @@ namespace Gecode {
     e.rel(home,icl);
   }
 
+  /*
+   * Boolean element constraints
+   *
+   */
+  
+  /// \brief Boolean element expressions
+  class BElementExpr : public BoolExpr::MiscExpr {
+  public:
+    /// The Boolean expressions
+    BoolExpr* a;
+    /// The number of Boolean expressions
+    int n;
+    /// The linear expression for the index
+    LinExpr idx;
+    /// Constructor
+    BElementExpr(int size);
+    /// Destructor
+    virtual ~BElementExpr(void);
+    /// Constrain \a b to be equivalent to the expression (negated if \a neg)
+    virtual void post(Space& home, BoolVar b, bool neg, IntConLevel icl);
+  };
+
+  BElementExpr::BElementExpr(int size)
+    : a(heap.alloc<BoolExpr>(size)), n(size) {}
+
+  BElementExpr::~BElementExpr(void) {
+    heap.free<BoolExpr>(a,n);
+  }
+  
+  void
+  BElementExpr::post(Space& home, BoolVar b, bool pos, IntConLevel icl) {
+    IntVar z = idx.post(home, icl);
+    if (z.assigned() && z.val() >= 0 && z.val() < n) {
+      BoolExpr be = pos ? (a[z.val()] == b) : (a[z.val()] == !b);
+      be.rel(home,icl);
+    } else {
+      BoolVarArgs x(n);
+      for (int i=n; i--;)
+        x[i] = a[i].expr(home,icl);
+      BoolVar res = pos ? b : (!b).expr(home,icl);
+      element(home, x, z, res, icl);
+    }
+  }
+
+  BoolExpr
+  element(const BoolVarArgs& b, const LinExpr& idx) {
+    BElementExpr* be = new BElementExpr(b.size());
+    for (int i=b.size(); i--;)
+      new (&be->a[i]) BoolExpr(b[i]);
+    be->idx = idx;
+    return BoolExpr(be);
+  }
+
 }
 
 // STATISTICS: minimodel-any
