@@ -7,8 +7,8 @@
  *     Christian Schulte, 2009
  *
  *  Last modified:
- *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10364 $
+ *     $Date: 2010-07-15 12:52:54 +0200 (Thu, 15 Jul 2010) $ by $Author: tack $
+ *     $Revision: 11200 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -37,13 +37,13 @@
 
 namespace Gecode { namespace Scheduling {
 
-  template<class OptTask>
+  template<class OptTask, PropCond pc>
   ExecStatus
   purge(Space& home, Propagator& p, TaskArray<OptTask>& t) {
     int n=t.size();
     for (int i=n; i--; )
       if (t[i].excluded()) {
-        t[i].cancel(home,p); t[i]=t[--n];
+        t[i].cancel(home,p,pc); t[i]=t[--n];
       }
     t.size(n);
 
