@@ -7,8 +7,8 @@
  *     Christian Schulte, 2009
  *
  *  Last modified:
- *     $Date: 2010-04-06 21:44:01 +0200 (Tue, 06 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10654 $
+ *     $Date: 2010-07-15 12:52:54 +0200 (Thu, 15 Jul 2010) $ by $Author: tack $
+ *     $Revision: 11200 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -42,12 +42,12 @@ namespace Gecode { namespace Scheduling { namespace Unary {
   template<class OptTask>
   forceinline
   OptProp<OptTask>::OptProp(Home home, TaskArray<OptTask>& t)
-    : TaskProp<OptTask>(home,t) {}
+    : TaskProp<OptTask,Int::PC_INT_BND>(home,t) {}
 
   template<class OptTask>
   forceinline
   OptProp<OptTask>::OptProp(Space& home, bool shared, OptProp<OptTask>& p) 
-    : TaskProp<OptTask>(home,shared,p) {}
+    : TaskProp<OptTask,Int::PC_INT_BND>(home,shared,p) {}
 
   template<class OptTask>
   forceinline ExecStatus 
@@ -62,7 +62,7 @@ namespace Gecode { namespace Scheduling { namespace Unary {
     if (m == t.size()) {
       TaskArray<typename TaskTraits<OptTask>::ManTask> mt(home,m);
       for (int i=m; i--; )
-        mt[i].init(t[i].st(),t[i].p());
+        mt[i].init(t[i]);
       return ManProp<typename TaskTraits<OptTask>::ManTask>::post(home,mt);
     }
     if (o+m > 1)
@@ -81,7 +81,7 @@ namespace Gecode { namespace Scheduling { namespace Unary {
   OptProp<OptTask>::propagate(Space& home, const ModEventDelta& med) {
     // Did one of the Boolean views change?
     if (Int::BoolView::me(med) == Int::ME_BOOL_VAL)
-      GECODE_ES_CHECK(purge(home,*this,t));
+      GECODE_ES_CHECK((purge<OptTask,Int::PC_INT_BND>(home,*this,t)));
 
     GECODE_ES_CHECK(overload(home,*this,t));
 
