@@ -11,8 +11,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10364 $
+ *     $Date: 2010-07-28 16:13:53 +0200 (Wed, 28 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11292 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -75,9 +75,11 @@ namespace Gecode { namespace Set { namespace Convex {
 
     //I + III
 
+    Region r(home);
     LubRanges<SetView> ubRangeIt(x0);
-    Iter::Ranges::Cache< LubRanges<SetView> > ubRangeItC(ubRangeIt);
-    for (;ubRangeItC();++ubRangeItC){
+    Iter::Ranges::Cache< LubRanges<SetView> > ubRangeItC(r,ubRangeIt);
+
+    for (; ubRangeItC(); ++ubRangeItC) {
       if (ubRangeItC.width() < (unsigned int) x0.cardMin()
           || ubRangeItC.min() > x0.glbMin() //No need to test for empty lb.
           || ubRangeItC.max() < x0.glbMax()
@@ -85,7 +87,8 @@ namespace Gecode { namespace Set { namespace Convex {
         GECODE_ME_CHECK( x0.exclude(home,ubRangeItC.min(), ubRangeItC.max()) );
       }
     }
-    if (x0.assigned()) {return home.ES_SUBSUMED(*this);}
+    if (x0.assigned()) 
+      return home.ES_SUBSUMED(*this);
     return ES_FIX;
   }
 
