@@ -13,8 +13,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10364 $
+ *     $Date: 2010-07-28 16:13:53 +0200 (Wed, 28 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11292 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -75,8 +75,9 @@ namespace Gecode { namespace Set { namespace Convex {
 
       unsigned int cardMin = x1.cardMin();
 
+      Region r(home);
       LubRanges<SetView> ubRangeIt(x1);
-      Iter::Ranges::Cache< LubRanges<SetView> > ubRangeItC(ubRangeIt);
+      Iter::Ranges::Cache< LubRanges<SetView> > ubRangeItC(r,ubRangeIt);
       for (;ubRangeItC();++ubRangeItC){
         if (ubRangeItC.width() < cardMin
             || ubRangeItC.min() > minElement //No need to test for empty lb.
