@@ -7,8 +7,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2010-07-14 17:46:18 +0200 (Wed, 14 Jul 2010) $ by $Author: schulte $
- *     $Revision: 11192 $
+ *     $Date: 2010-09-03 16:36:31 +0200 (Fri, 03 Sep 2010) $ by $Author: schulte $
+ *     $Revision: 11390 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -65,12 +65,10 @@ namespace Gecode { namespace Set { namespace Distinct {
     for (int i = x.size(); i--; ) {
       lubs[i].init(x[i]);
     }
-    Iter::Ranges::NaryUnion<LubRanges<SetView> > bigT(lubs, x.size());
-    Iter::Ranges::Cache<Iter::Ranges::NaryUnion<LubRanges<SetView> > >
-      bigTC(bigT);
+    Iter::Ranges::NaryUnion<LubRanges<SetView> > bigT(r, lubs, x.size());
 
-    Iter::Ranges::ToValues<Iter::Ranges::Cache<Iter::Ranges::NaryUnion<LubRanges<SetView> > > >
-      as(bigTC);
+    Iter::Ranges::ToValues<Iter::Ranges::NaryUnion<LubRanges<SetView> > >
+      as(bigT);
 
     while (as()) {
       int a = as.val(); ++as;
@@ -113,7 +111,7 @@ namespace Gecode { namespace Set { namespace Distinct {
         for (int i = x.size(); i--; ) {
           lubs2[i].init(x[i]);
         }
-        Iter::Ranges::NaryUnion<LubRanges<SetView> > bigT2(lubs2, x.size());
+        Iter::Ranges::NaryUnion<LubRanges<SetView> > bigT2(r, lubs2, x.size());
 
         GlbRanges<SetView>* glbs = r.alloc<GlbRanges<SetView> >(cardSa);
         int count = 0;
@@ -123,12 +121,12 @@ namespace Gecode { namespace Set { namespace Distinct {
             count++;
           }
         }
-        Iter::Ranges::NaryUnion<GlbRanges<SetView> > glbsa(glbs, cardSa);
+        Iter::Ranges::NaryUnion<GlbRanges<SetView> > glbsa(r, glbs, cardSa);
         Iter::Ranges::Diff<Iter::Ranges::NaryUnion<LubRanges<SetView> >,
           Iter::Ranges::NaryUnion<GlbRanges<SetView> > > deltaA(bigT2, glbsa);
         Iter::Ranges::Cache<
         Iter::Ranges::Diff<Iter::Ranges::NaryUnion<LubRanges<SetView> >,
-          Iter::Ranges::NaryUnion<GlbRanges<SetView> > > > deltaAC(deltaA);
+          Iter::Ranges::NaryUnion<GlbRanges<SetView> > > > deltaAC(r,deltaA);
         // deltaAC contains all elements that are not yet known to be
         // in a set together with a.
         // Formally: \cup_i lub(x_i) - \cup_i {glb(s_i) | a\in glb(s_i)}
