@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2010-07-14 17:46:18 +0200 (Wed, 14 Jul 2010) $ by $Author: schulte $
- *     $Revision: 11192 $
+ *     $Date: 2010-07-28 16:13:53 +0200 (Wed, 28 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11292 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -116,12 +116,12 @@ namespace Gecode { namespace Set { namespace Element {
       // Cache the upper bound iterator, as we have to
       // modify the upper bound while iterating
       LubRanges<RView> x1ub(x1);
-      Iter::Ranges::Cache<LubRanges<RView> > x1ubc(x1ub);
+      Iter::Ranges::Cache<LubRanges<RView> > x1ubc(r,x1ub);
       Iter::Ranges::ToValues<Iter::Ranges::Cache<LubRanges<RView> > >
         vx1ub(x1ubc);
 
       GlbRanges<RView> x1lb(x1);
-      Iter::Ranges::Cache<GlbRanges<RView> > x1lbc(x1lb);
+      Iter::Ranges::Cache<GlbRanges<RView> > x1lbc(r,x1lb);
       Iter::Ranges::ToValues<Iter::Ranges::Cache<GlbRanges<RView> > >
         vx1(x1lbc);
 
