@@ -11,8 +11,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2010-07-14 17:46:18 +0200 (Wed, 14 Jul 2010) $ by $Author: schulte $
- *     $Revision: 11192 $
+ *     $Date: 2010-07-28 17:35:33 +0200 (Wed, 28 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11294 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -46,7 +46,7 @@ namespace Gecode { namespace Set { namespace Int {
 
   /// Value Iterator for values above a certain weight
   template<class I>
-  class OverweightValues : public Iter::Values::IsValueIter<I> {
+  class OverweightValues {
   private:
     /// The threshold above which values should be iterated
     int threshold;
