@@ -13,8 +13,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-09-03 16:36:31 +0200 (Fri, 03 Sep 2010) $ by $Author: schulte $
+ *     $Revision: 11390 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -579,7 +579,7 @@ namespace Set { namespace RelOp {
     }
     if (nonEmptyCounter !=0) {
       Iter::Ranges::NaryUnion<GlbRanges<View0> >
-        xLBUnion(xLBs,nonEmptyCounter);
+        xLBUnion(r,xLBs,nonEmptyCounter);
       BndSetRanges dets(unionOfDets);
       Iter::Ranges::Union<Iter::Ranges::NaryUnion<GlbRanges<View0> >,
         BndSetRanges>
@@ -608,7 +608,7 @@ namespace Set { namespace RelOp {
     }
     if (nonEmptyCounter !=0) {
       Iter::Ranges::NaryUnion<LubRanges<View0> >
-        xUBUnion(xUBs,nonEmptyCounter);
+        xUBUnion(r,xUBs,nonEmptyCounter);
       BndSetRanges dets(unionOfDets);
       Iter::Ranges::Union<Iter::Ranges::NaryUnion<LubRanges<View0> >,
         BndSetRanges>
