@@ -11,8 +11,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2010-06-29 10:39:13 +0200 (Tue, 29 Jun 2010) $ by $Author: schulte $
- *     $Revision: 11118 $
+ *     $Date: 2010-08-31 17:19:33 +0200 (Tue, 31 Aug 2010) $ by $Author: schulte $
+ *     $Revision: 11368 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -57,9 +57,9 @@ namespace Gecode { namespace Set {
    * \ingroup TaskActorSetView
    */
 
-  class SetView : public VarImpView<SetVarImp> {
+  class SetView : public VarImpView<SetVar> {
   protected:
-    using VarImpView<SetVarImp>::x;
+    using VarImpView<SetVar>::x;
   public:
     /// \name Constructors and initialization
     //@{
