@@ -9,8 +9,8 @@
  *     Mikael Lagerkvist, 2005
  *
  *  Last modified:
- *     $Date: 2009-05-08 13:44:41 +0200 (Fri, 08 May 2009) $ by $Author: schulte $
- *     $Revision: 9034 $
+ *     $Date: 2010-06-03 13:11:11 +0200 (Thu, 03 Jun 2010) $ by $Author: tack $
+ *     $Revision: 11013 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -70,6 +70,15 @@ namespace Test { namespace Int {
     a--;
   }
 
+  void
+  RandomMixAssignment::operator++(void) {
+    for (int i=n-_n1; i--; )
+      vals[i] = randval(d);
+    for (int i=_n1; i--; )
+      vals[n-_n1+i] = randval(_d1);
+    a--;
+  }
+
 }}
 
 std::ostream&
@@ -232,7 +241,7 @@ namespace Test { namespace Int {
   }
 
   bool 
-  TestSpace::prune(const Assignment& a) {
+  TestSpace::prune(const Assignment& a, bool testfix) {
     // Select variable to be pruned
     int i = Base::rand(x.size());
     while (x[i].assigned())
@@ -281,7 +290,7 @@ namespace Test { namespace Int {
       }
     }
     if (Base::fixpoint()) {
-      if (failed())
+      if (failed() || !testfix)
         return true;
       TestSpace* c = static_cast<TestSpace*>(clone());
       if (opt.log)
@@ -463,7 +472,7 @@ if (!(T)) {                                                     \
         TestSpace* s = new TestSpace(arity,dom,false,this);
         s->post();
         while (!s->failed() && !s->assigned())
-          if (!s->prune(a)) {
+          if (!s->prune(a,testfix)) {
             problem = "No fixpoint";
             delete s;
             goto failed;
@@ -534,7 +543,7 @@ if (!(T)) {                                                     \
           TestSpace* s = new TestSpace(arity,dom,true,this);
           s->post();
           while (!s->failed() && (!s->assigned() || !s->b.assigned()))
-            if (!s->prune(a)) {
+            if (!s->prune(a,testfix)) {
               problem = "No fixpoint";
               delete s;
               goto failed;
