@@ -7,8 +7,8 @@
  *     Mikael Lagerkvist, 2005
  *
  *  Last modified:
- *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10684 $
+ *     $Date: 2010-05-08 12:56:03 +0200 (Sat, 08 May 2010) $ by $Author: tack $
+ *     $Revision: 10906 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -74,10 +74,10 @@ namespace Test { namespace Int {
        Ass(int n, const Gecode::IntSet& d) : x(*this, n, d) {
          using namespace Gecode;
          for (int i = 0; i < n; i += 4) {
-           post(*this, x[i+0] >= 0);
-           post(*this, x[i+1] >= 0);
-           post(*this, x[i+2] >= 0);
-           post(*this, x[i] + x[i+1] == x[i+2]);
+           rel(*this, x[i+0] >= 0);
+           rel(*this, x[i+1] >= 0);
+           rel(*this, x[i+2] >= 0);
+           rel(*this, x[i] + x[i+1] == x[i+2]);
            branch(*this, x, INT_VAR_NONE, INT_VAL_MIN);
          }
        }
