@@ -7,8 +7,8 @@
  *     Guido Tack, 2005
  *
  *  Last modified:
- *     $Date: 2010-05-31 13:53:25 +0200 (Mon, 31 May 2010) $ by $Author: tack $
- *     $Revision: 10995 $
+ *     $Date: 2010-09-03 16:36:31 +0200 (Fri, 03 Sep 2010) $ by $Author: schulte $
+ *     $Revision: 11390 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -78,11 +78,18 @@ namespace Test { namespace Set {
           }
           sel[i].init(x.lub, x[selector.val()]);
         }
-        Iter::Ranges::NaryUnion<CountableSetRanges> u(sel, selected);
-
-        CountableSetRanges z(x.lub, x[4]);
-        bool ret = Iter::Ranges::equal(u, z);
+        
+        FakeSpace* fs = new FakeSpace;
+        bool ret;
+        {
+          Region r(*fs);
+          Iter::Ranges::NaryUnion<CountableSetRanges> u(r, sel, selected);
+          
+          CountableSetRanges z(x.lub, x[4]);
+          ret = Iter::Ranges::equal(u, z);
+        }
         delete[] sel;
+        delete fs;
         return ret;
       }
       /// Post constraint on \a x
@@ -123,11 +130,18 @@ namespace Test { namespace Set {
           }
           sel[i].init(iss[selector.val()]);
         }
-        Iter::Ranges::NaryUnion<IntSetRanges> u(sel, selected);
 
-        CountableSetRanges z(x.lub, x[1]);
-        bool ret = Iter::Ranges::equal(u, z);
+        FakeSpace* fs = new FakeSpace;
+        bool ret;
+        {
+          Region r(*fs);
+          Iter::Ranges::NaryUnion<IntSetRanges> u(r, sel, selected);
+
+          CountableSetRanges z(x.lub, x[1]);
+          ret = Iter::Ranges::equal(u, z);
+        }
         delete[] sel;
+        delete fs;
         return ret;
       }
       /// Post constraint on \a x
@@ -249,13 +263,18 @@ namespace Test { namespace Set {
           CountableSetRanges xicard(x.lub, x[selector.val()]);
           cardsum += Iter::Ranges::size(xicard);
         }
-        Iter::Ranges::NaryUnion<CountableSetRanges> u(sel, selected);
-        Iter::Ranges::Cache<Iter::Ranges::NaryUnion<CountableSetRanges> >
-          uc(u);
-        bool ret = Iter::Ranges::size(uc) == cardsum;
-        uc.reset();
-        CountableSetRanges z(x.lub, x[4]);
-        ret &= Iter::Ranges::equal(uc, z);
+        
+        bool ret;
+        FakeSpace* fs = new FakeSpace;
+        {
+          Region r(*fs);
+          Iter::Ranges::NaryUnion<CountableSetRanges> u(r, sel, selected);
+          ret = Iter::Ranges::size(u) == cardsum;
+          u.reset();
+          CountableSetRanges z(x.lub, x[4]);
+          ret &= Iter::Ranges::equal(u, z);
+        }
+        delete fs;
         delete[] sel;
         return ret;
       }
