@@ -7,8 +7,8 @@
  *     Guido Tack, 2005
  *
  *  Last modified:
- *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10684 $
+ *     $Date: 2010-09-03 16:36:31 +0200 (Fri, 03 Sep 2010) $ by $Author: schulte $
+ *     $Revision: 11390 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -104,10 +104,16 @@ namespace Test { namespace Set {
         CountableSetRanges* isrs = new CountableSetRanges[n];
         for (int i=n; i--; )
           isrs[i].init(x.lub, x[i]);
-        Iter::Ranges::NaryUnion<CountableSetRanges> u(isrs, n);
-        CountableSetRanges xnr(x.lub, x[n]);
-        bool ret = Iter::Ranges::equal(u, xnr);
+        FakeSpace* fs = new FakeSpace;
+        bool ret;
+        {
+          Region r(*fs);
+          Iter::Ranges::NaryUnion<CountableSetRanges> u(r, isrs, n);
+          CountableSetRanges xnr(x.lub, x[n]);
+          ret = Iter::Ranges::equal(u, xnr);
+        }
         delete[] isrs;
+        delete fs;
         return ret;
       }
       /// Post constraint on \a x
